<?php
/**
 * Theme sprecific functions and definitions
 */


/* Theme setup section
------------------------------------------------------------------- */

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1170; /* pixels */

// Add theme specific actions and filters
// Attention! Function were add theme specific actions and filters handlers must have priority 1
if ( !function_exists( 'bierbaum_theme_setup' ) ) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_theme_setup', 1 );
	function bierbaum_theme_setup() {

		// Register theme menus
		add_filter( 'bierbaum_filter_add_theme_menus',		'bierbaum_add_theme_menus' );

		// Register theme sidebars
		add_filter( 'bierbaum_filter_add_theme_sidebars',	'bierbaum_add_theme_sidebars' );

		// Set options for importer
		add_filter( 'bierbaum_filter_importer_options',		'bierbaum_set_importer_options' );

		// Add theme specified classes into the body
		add_filter( 'body_class', 'bierbaum_body_classes' );

		// Set list of the theme required plugins
		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['required_plugins'] = array(
			'essgrids',
			'instagram_widget',
			'revslider',
			'trx_donations',
			'trx_utils',
			'visual_composer'
		);

	}
}


// Add/Remove theme nav menus
if ( !function_exists( 'bierbaum_add_theme_menus' ) ) {
	function bierbaum_add_theme_menus($menus) {
		//For example:
		return $menus;
	}
}


// Add theme specific widgetized areas
if ( !function_exists( 'bierbaum_add_theme_sidebars' ) ) {

	function bierbaum_add_theme_sidebars($sidebars=array()) {
		if (is_array($sidebars)) {
			$theme_sidebars = array(
				'sidebar_main'		=> esc_html__( 'Main Sidebar', 'bierbaum' ),
				'sidebar_footer'	=> esc_html__( 'Footer Sidebar', 'bierbaum' )
			);
			if (function_exists('bierbaum_exists_woocommerce') && bierbaum_exists_woocommerce()) {
				$theme_sidebars['sidebar_cart']  = esc_html__( 'WooCommerce Cart Sidebar', 'bierbaum' );
			}
			$sidebars = array_merge($theme_sidebars, $sidebars);
		}
		return $sidebars;
	}
}


// Add theme specified classes into the body
if ( !function_exists('bierbaum_body_classes') ) {

	function bierbaum_body_classes( $classes ) {

		$classes[] = 'bierbaum_body';
		$classes[] = 'body_style_' . trim(bierbaum_get_custom_option('body_style'));
		$classes[] = 'body_' . (bierbaum_get_custom_option('body_filled')=='yes' ? 'filled' : 'transparent');
		$classes[] = 'theme_skin_' . trim(bierbaum_get_custom_option('theme_skin'));
		$classes[] = 'article_style_' . trim(bierbaum_get_custom_option('article_style'));
		
		$blog_style = bierbaum_get_custom_option(is_singular() && !bierbaum_get_global('blog_streampage') ? 'single_style' : 'blog_style');
		$classes[] = 'layout_' . trim($blog_style);
		$classes[] = 'template_' . trim(bierbaum_get_template_name($blog_style));
		
		$body_scheme = bierbaum_get_custom_option('body_scheme');
		if (empty($body_scheme)  || bierbaum_is_inherit_option($body_scheme)) $body_scheme = 'original';
		$classes[] = 'scheme_' . $body_scheme;

		$top_panel_position = bierbaum_get_custom_option('top_panel_position');
		if (!bierbaum_param_is_off($top_panel_position)) {
			$classes[] = 'top_panel_show';
			$classes[] = 'top_panel_' . trim($top_panel_position);
		} else 
			$classes[] = 'top_panel_hide';
		$classes[] = bierbaum_get_sidebar_class();

		if (bierbaum_get_custom_option('show_video_bg')=='yes' && (bierbaum_get_custom_option('video_bg_youtube_code')!='' || bierbaum_get_custom_option('video_bg_url')!=''))
			$classes[] = 'video_bg_show';

		if (bierbaum_get_theme_option('page_preloader')!='')
			$classes[] = 'preloader';

		return $classes;

	}
}





// Set theme specific importer options
if ( !function_exists( 'bierbaum_set_importer_options' ) ) {
	//add_filter( 'bierbaum_filter_importer_options',	'bierbaum_set_importer_options' );
	function bierbaum_set_importer_options($options=array()) {
		if (is_array($options)) {
			$options['debug'] = bierbaum_get_theme_option('debug_mode')=='yes';
			$options['domain_dev'] = '_trex2.themerex.dnw';
			$options['domain_demo'] = 'trex2.dev.themerex.net';
			$options['menus'] = array(
				'menu-main'	  => esc_html__('Main menu', 'bierbaum'),
				'menu-user'	  => esc_html__('User menu', 'bierbaum'),
				'menu-footer' => esc_html__('Footer menu', 'bierbaum'),
				'menu-outer'  => esc_html__('Main menu', 'bierbaum')
			);
		}
		return $options;
	}
}


/* Include framework core files
------------------------------------------------------------------- */
// If now is WP Heartbeat call - skip loading theme core files
	require_once get_template_directory().'/fw/loader.php';

?>