<?php
/**
 * BierBaum Framework: messages subsystem
 *
 * @package	bierbaum
 * @since	bierbaum 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('bierbaum_messages_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_messages_theme_setup' );
	function bierbaum_messages_theme_setup() {
		// Core messages strings
		add_action('bierbaum_action_add_scripts_inline', 'bierbaum_messages_add_scripts_inline');
	}
}


/* Session messages
------------------------------------------------------------------------------------- */

if (!function_exists('bierbaum_get_error_msg')) {
	function bierbaum_get_error_msg() {
		global $BIERBAUM_GLOBALS;
		return !empty($BIERBAUM_GLOBALS['error_msg']) ? $BIERBAUM_GLOBALS['error_msg'] : '';
	}
}

if (!function_exists('bierbaum_set_error_msg')) {
	function bierbaum_set_error_msg($msg) {
		global $BIERBAUM_GLOBALS;
		$msg2 = bierbaum_get_error_msg();
		$BIERBAUM_GLOBALS['error_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}

if (!function_exists('bierbaum_get_success_msg')) {
	function bierbaum_get_success_msg() {
		global $BIERBAUM_GLOBALS;
		return !empty($BIERBAUM_GLOBALS['success_msg']) ? $BIERBAUM_GLOBALS['success_msg'] : '';
	}
}

if (!function_exists('bierbaum_set_success_msg')) {
	function bierbaum_set_success_msg($msg) {
		global $BIERBAUM_GLOBALS;
		$msg2 = bierbaum_get_success_msg();
		$BIERBAUM_GLOBALS['success_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}

if (!function_exists('bierbaum_get_notice_msg')) {
	function bierbaum_get_notice_msg() {
		global $BIERBAUM_GLOBALS;
		return !empty($BIERBAUM_GLOBALS['notice_msg']) ? $BIERBAUM_GLOBALS['notice_msg'] : '';
	}
}

if (!function_exists('bierbaum_set_notice_msg')) {
	function bierbaum_set_notice_msg($msg) {
		global $BIERBAUM_GLOBALS;
		$msg2 = bierbaum_get_notice_msg();
		$BIERBAUM_GLOBALS['notice_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}


/* System messages (save when page reload)
------------------------------------------------------------------------------------- */
if (!function_exists('bierbaum_set_system_message')) {
	function bierbaum_set_system_message($msg, $status='info', $hdr='') {
		update_option('bierbaum_message', array('message' => $msg, 'status' => $status, 'header' => $hdr));
	}
}

if (!function_exists('bierbaum_get_system_message')) {
	function bierbaum_get_system_message($del=false) {
		$msg = get_option('bierbaum_message', false);
		if (!$msg)
			$msg = array('message' => '', 'status' => '', 'header' => '');
		else if ($del)
			bierbaum_del_system_message();
		return $msg;
	}
}

if (!function_exists('bierbaum_del_system_message')) {
	function bierbaum_del_system_message() {
		delete_option('bierbaum_message');
	}
}


/* Messages strings
------------------------------------------------------------------------------------- */

if (!function_exists('bierbaum_messages_add_scripts_inline')) {
	function bierbaum_messages_add_scripts_inline() {
		global $BIERBAUM_GLOBALS;
		echo '<script type="text/javascript">'
			
			. "if (typeof BIERBAUM_GLOBALS == 'undefined') var BIERBAUM_GLOBALS = {};"
			
			// Strings for translation
			. 'BIERBAUM_GLOBALS["strings"] = {'
				. 'ajax_error: 			"' . addslashes(esc_html__('Invalid server answer', 'bierbaum')) . '",'
				. 'bookmark_add: 		"' . addslashes(esc_html__('Add the bookmark', 'bierbaum')) . '",'
				. 'bookmark_added:		"' . addslashes(esc_html__('Current page has been successfully added to the bookmarks. You can see it in the right panel on the tab \'Bookmarks\'', 'bierbaum')) . '",'
				. 'bookmark_del: 		"' . addslashes(esc_html__('Delete this bookmark', 'bierbaum')) . '",'
				. 'bookmark_title:		"' . addslashes(esc_html__('Enter bookmark title', 'bierbaum')) . '",'
				. 'bookmark_exists:		"' . addslashes(esc_html__('Current page already exists in the bookmarks list', 'bierbaum')) . '",'
				. 'search_error:		"' . addslashes(esc_html__('Error occurs in AJAX search! Please, type your query and press search icon for the traditional search way.', 'bierbaum')) . '",'
				. 'email_confirm:		"' . addslashes(esc_html__('On the e-mail address "%s" we sent a confirmation email. Please, open it and click on the link.', 'bierbaum')) . '",'
				. 'reviews_vote:		"' . addslashes(esc_html__('Thanks for your vote! New average rating is:', 'bierbaum')) . '",'
				. 'reviews_error:		"' . addslashes(esc_html__('Error saving your vote! Please, try again later.', 'bierbaum')) . '",'
				. 'error_like:			"' . addslashes(esc_html__('Error saving your like! Please, try again later.', 'bierbaum')) . '",'
				. 'error_global:		"' . addslashes(esc_html__('Global error text', 'bierbaum')) . '",'
				. 'name_empty:			"' . addslashes(esc_html__('The name can\'t be empty', 'bierbaum')) . '",'
				. 'name_long:			"' . addslashes(esc_html__('Too long name', 'bierbaum')) . '",'
				. 'email_empty:			"' . addslashes(esc_html__('Too short (or empty) email address', 'bierbaum')) . '",'
				. 'email_long:			"' . addslashes(esc_html__('Too long email address', 'bierbaum')) . '",'
				. 'email_not_valid:		"' . addslashes(esc_html__('Invalid email address', 'bierbaum')) . '",'
				. 'subject_empty:		"' . addslashes(esc_html__('The subject can\'t be empty', 'bierbaum')) . '",'
				. 'subject_long:		"' . addslashes(esc_html__('Too long subject', 'bierbaum')) . '",'
				. 'text_empty:			"' . addslashes(esc_html__('The message text can\'t be empty', 'bierbaum')) . '",'
				. 'text_long:			"' . addslashes(esc_html__('Too long message text', 'bierbaum')) . '",'
				. 'send_complete:		"' . addslashes(esc_html__("Send message complete!", 'bierbaum')) . '",'
				. 'send_error:			"' . addslashes(esc_html__('Transmit failed!', 'bierbaum')) . '",'
				. 'login_empty:			"' . addslashes(esc_html__('The Login field can\'t be empty', 'bierbaum')) . '",'
				. 'login_long:			"' . addslashes(esc_html__('Too long login field', 'bierbaum')) . '",'
				. 'login_success:		"' . addslashes(esc_html__('Login success! The page will be reloaded in 3 sec.', 'bierbaum')) . '",'
				. 'login_failed:		"' . addslashes(esc_html__('Login failed!', 'bierbaum')) . '",'
				. 'password_empty:		"' . addslashes(esc_html__('The password can\'t be empty and shorter then 4 characters', 'bierbaum')) . '",'
				. 'password_long:		"' . addslashes(esc_html__('Too long password', 'bierbaum')) . '",'
				. 'password_not_equal:	"' . addslashes(esc_html__('The passwords in both fields are not equal', 'bierbaum')) . '",'
				. 'registration_success:"' . addslashes(esc_html__('Registration success! Please log in!', 'bierbaum')) . '",'
				. 'registration_failed:	"' . addslashes(esc_html__('Registration failed!', 'bierbaum')) . '",'
				. 'geocode_error:		"' . addslashes(esc_html__('Geocode was not successful for the following reason:', 'bierbaum')) . '",'
				. 'googlemap_not_avail:	"' . addslashes(esc_html__('Google map API not available!', 'bierbaum')) . '",'
				. 'editor_save_success:	"' . addslashes(esc_html__("Post content saved!", 'bierbaum')) . '",'
				. 'editor_save_error:	"' . addslashes(esc_html__("Error saving post data!", 'bierbaum')) . '",'
				. 'editor_delete_post:	"' . addslashes(esc_html__("You really want to delete the current post?", 'bierbaum')) . '",'
				. 'editor_delete_post_header:"' . addslashes(esc_html__("Delete post", 'bierbaum')) . '",'
				. 'editor_delete_success:	"' . addslashes(esc_html__("Post deleted!", 'bierbaum')) . '",'
				. 'editor_delete_error:		"' . addslashes(esc_html__("Error deleting post!", 'bierbaum')) . '",'
				. 'editor_caption_cancel:	"' . addslashes(esc_html__('Cancel', 'bierbaum')) . '",'
				. 'editor_caption_close:	"' . addslashes(esc_html__('Close', 'bierbaum')) . '"'
				. '};'
			
			. '</script>';
	}
}
?>