<?php
/**
 * BierBaum Framework: shortcodes manipulations
 *
 * @package	bierbaum
 * @since	bierbaum 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('bierbaum_sc_theme_setup')) {
	add_action( 'bierbaum_action_init_theme', 'bierbaum_sc_theme_setup', 1 );
	function bierbaum_sc_theme_setup() {
		// Add sc stylesheets
		add_action('bierbaum_action_add_styles', 'bierbaum_sc_add_styles', 1);
	}
}

if (!function_exists('bierbaum_sc_theme_setup2')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_theme_setup2' );
	function bierbaum_sc_theme_setup2() {

		if ( !is_admin() || isset($_POST['action']) ) {
			// Enable/disable shortcodes in excerpt
			add_filter('the_excerpt', 					'bierbaum_sc_excerpt_shortcodes');
	
			// Prepare shortcodes in the content
			if (function_exists('bierbaum_sc_prepare_content')) bierbaum_sc_prepare_content();
		}

		// Add init script into shortcodes output in VC frontend editor
		add_filter('bierbaum_shortcode_output', 'bierbaum_sc_add_scripts', 10, 4);

		// AJAX: Send contact form data
		add_action('wp_ajax_send_form',			'bierbaum_sc_form_send');
		add_action('wp_ajax_nopriv_send_form',	'bierbaum_sc_form_send');

		// Show shortcodes list in admin editor
		add_action('media_buttons',				'bierbaum_sc_selector_add_in_toolbar', 11);

	}
}


// Add shortcodes styles
if ( !function_exists( 'bierbaum_sc_add_styles' ) ) {
	//add_action('bierbaum_action_add_styles', 'bierbaum_sc_add_styles', 1);
	function bierbaum_sc_add_styles() {
		// Shortcodes
		bierbaum_enqueue_style( 'bierbaum-shortcodes-style',	bierbaum_get_file_url('shortcodes/theme.shortcodes.css'), array(), null );
	}
}


// Add shortcodes init scripts
if ( !function_exists( 'bierbaum_sc_add_scripts' ) ) {
	//add_filter('bierbaum_shortcode_output', 'bierbaum_sc_add_scripts', 10, 4);
	function bierbaum_sc_add_scripts($output, $tag='', $atts=array(), $content='') {

		global $BIERBAUM_GLOBALS;
		
		if (empty($BIERBAUM_GLOBALS['shortcodes_scripts_added'])) {
			$BIERBAUM_GLOBALS['shortcodes_scripts_added'] = true;
			//bierbaum_enqueue_style( 'bierbaum-shortcodes-style', bierbaum_get_file_url('shortcodes/theme.shortcodes.css'), array(), null );
			bierbaum_enqueue_script( 'bierbaum-shortcodes-script', bierbaum_get_file_url('shortcodes/theme.shortcodes.js'), array('jquery'), null, true );	
		}
		
		return $output;
	}
}


/* Prepare text for shortcodes
-------------------------------------------------------------------------------- */

// Prepare shortcodes in content
if (!function_exists('bierbaum_sc_prepare_content')) {
	function bierbaum_sc_prepare_content() {
		if (function_exists('bierbaum_sc_clear_around')) {
			$filters = array(
				array('bierbaum', 'sc', 'clear', 'around'),
				array('widget', 'text'),
				array('the', 'excerpt'),
				array('the', 'content')
			);
			if (function_exists('bierbaum_exists_woocommerce') && bierbaum_exists_woocommerce()) {
				$filters[] = array('woocommerce', 'template', 'single', 'excerpt');
				$filters[] = array('woocommerce', 'short', 'description');
			}
			if (is_array($filters) && count($filters) > 0) {
				foreach ($filters as $flt)
					add_filter(join('_', $flt), 'bierbaum_sc_clear_around', 1);	// Priority 1 to clear spaces before do_shortcodes()
			}
		}
	}
}

// Enable/Disable shortcodes in the excerpt
if (!function_exists('bierbaum_sc_excerpt_shortcodes')) {
	function bierbaum_sc_excerpt_shortcodes($content) {
		if (!empty($content)) {
			$content = do_shortcode($content);
			//$content = strip_shortcodes($content);
		}
		return $content;
	}
}



/*
// Remove spaces and line breaks between close and open shortcode brackets ][:
[trx_columns]
	[trx_column_item]Column text ...[/trx_column_item]
	[trx_column_item]Column text ...[/trx_column_item]
	[trx_column_item]Column text ...[/trx_column_item]
[/trx_columns]

convert to

[trx_columns][trx_column_item]Column text ...[/trx_column_item][trx_column_item]Column text ...[/trx_column_item][trx_column_item]Column text ...[/trx_column_item][/trx_columns]
*/
if (!function_exists('bierbaum_sc_clear_around')) {
	function bierbaum_sc_clear_around($content) {
		if (!empty($content)) $content = preg_replace("/\](\s|\n|\r)*\[/", "][", $content);
		return $content;
	}
}






/* Shortcodes support utils
---------------------------------------------------------------------- */

// BierBaum shortcodes load scripts
if (!function_exists('bierbaum_sc_load_scripts')) {
	function bierbaum_sc_load_scripts() {
		bierbaum_enqueue_script( 'bierbaum-shortcodes-script', bierbaum_get_file_url('core/core.shortcodes/shortcodes_admin.js'), array('jquery'), null, true );
		bierbaum_enqueue_script( 'bierbaum-selection-script',  bierbaum_get_file_url('js/jquery.selection.js'), array('jquery'), null, true );
	}
}

// BierBaum shortcodes prepare scripts
if (!function_exists('bierbaum_sc_prepare_scripts')) {
	function bierbaum_sc_prepare_scripts() {
		global $BIERBAUM_GLOBALS;
		if (!isset($BIERBAUM_GLOBALS['shortcodes_prepared'])) {
			$BIERBAUM_GLOBALS['shortcodes_prepared'] = true;
			$json_parse_func = 'eval';	// 'JSON.parse'
			?>
			<script type="text/javascript">
				jQuery(document).ready(function(){
					try {
						BIERBAUM_GLOBALS['shortcodes'] = <?php echo trim($json_parse_func); ?>(<?php echo json_encode( bierbaum_array_prepare_to_json($BIERBAUM_GLOBALS['shortcodes']) ); ?>);
					} catch (e) {}
					BIERBAUM_GLOBALS['shortcodes_cp'] = '<?php echo is_admin() ? (!empty($BIERBAUM_GLOBALS['to_colorpicker']) ? $BIERBAUM_GLOBALS['to_colorpicker'] : 'wp') : 'custom'; ?>';	// wp | tiny | custom
				});
			</script>
			<?php
		}
	}
}

// Show shortcodes list in admin editor
if (!function_exists('bierbaum_sc_selector_add_in_toolbar')) {
	//add_action('media_buttons','bierbaum_sc_selector_add_in_toolbar', 11);
	function bierbaum_sc_selector_add_in_toolbar(){

		if ( !bierbaum_options_is_used() ) return;

		bierbaum_sc_load_scripts();
		bierbaum_sc_prepare_scripts();

		global $BIERBAUM_GLOBALS;

		$shortcodes = $BIERBAUM_GLOBALS['shortcodes'];
		$shortcodes_list = '<select class="sc_selector"><option value="">&nbsp;'.esc_html__('- Select Shortcode -', 'bierbaum').'&nbsp;</option>';

		if (is_array($shortcodes) && count($shortcodes) > 0) {
			foreach ($shortcodes as $idx => $sc) {
				$shortcodes_list .= '<option value="'.esc_attr($idx).'" title="'.esc_attr($sc['desc']).'">'.esc_html($sc['title']).'</option>';
			}
		}

		$shortcodes_list .= '</select>';

		echo trim($shortcodes_list);
	}
}

// BierBaum shortcodes builder settings
require_once bierbaum_get_file_dir('core/core.shortcodes/shortcodes_settings.php');

// VC shortcodes settings
if ( class_exists('WPBakeryShortCode') ) {
	require_once bierbaum_get_file_dir('core/core.shortcodes/shortcodes_vc.php');
}

// BierBaum shortcodes implementation
bierbaum_autoload_folder( 'shortcodes/trx_basic' );
bierbaum_autoload_folder( 'shortcodes/trx_optional' );
?>