<?php

// Check if shortcodes settings are now used
if ( !function_exists( 'bierbaum_shortcodes_is_used' ) ) {
	function bierbaum_shortcodes_is_used() {
		return bierbaum_options_is_used() 															// All modes when Theme Options are used
			|| (is_admin() && isset($_POST['action']) 
					&& in_array($_POST['action'], array('vc_edit_form', 'wpb_show_edit_form')))		// AJAX query when save post/page
			|| (is_admin() && bierbaum_strpos($_SERVER['REQUEST_URI'], 'vc-roles')!==false)			// VC Role Manager
			|| (function_exists('bierbaum_vc_is_frontend') && bierbaum_vc_is_frontend());			// VC Frontend editor mode
	}
}

// Width and height params
if ( !function_exists( 'bierbaum_shortcodes_width' ) ) {
	function bierbaum_shortcodes_width($w="") {
		return array(
			"title" => esc_html__("Width", "bierbaum"),
			"divider" => true,
			"value" => $w,
			"type" => "text"
		);
	}
}
if ( !function_exists( 'bierbaum_shortcodes_height' ) ) {
	function bierbaum_shortcodes_height($h='') {
		global $BIERBAUM_GLOBALS;
		return array(
			"title" => esc_html__("Height", "bierbaum"),
			"desc" => wp_kses( __("Width (in pixels or percent) and height (only in pixels) of element", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"value" => $h,
			"type" => "text"
		);
	}
}

/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'bierbaum_shortcodes_settings_theme_setup' ) ) {
//	if ( bierbaum_vc_is_frontend() )
	if ( (isset($_GET['vc_editable']) && $_GET['vc_editable']=='true') || (isset($_GET['vc_action']) && $_GET['vc_action']=='vc_inline') )
		add_action( 'bierbaum_action_before_init_theme', 'bierbaum_shortcodes_settings_theme_setup', 20 );
	else
		add_action( 'bierbaum_action_after_init_theme', 'bierbaum_shortcodes_settings_theme_setup' );
	function bierbaum_shortcodes_settings_theme_setup() {
		if (bierbaum_shortcodes_is_used()) {
			global $BIERBAUM_GLOBALS;

			// Sort templates alphabetically
			ksort($BIERBAUM_GLOBALS['registered_templates']);

			// Prepare arrays 
			$BIERBAUM_GLOBALS['sc_params'] = array(
			
				// Current element id
				'id' => array(
					"title" => esc_html__("Element ID", "bierbaum"),
					"desc" => wp_kses( __("ID for current element", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "",
					"type" => "text"
				),
			
				// Current element class
				'class' => array(
					"title" => esc_html__("Element CSS class", "bierbaum"),
					"desc" => wp_kses( __("CSS class for current element (optional)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
			
				// Current element style
				'css' => array(
					"title" => esc_html__("CSS styles", "bierbaum"),
					"desc" => wp_kses( __("Any additional CSS rules (if need)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
			
			
				// Switcher choises
				'list_styles' => array(
					'ul'	=> esc_html__('Unordered', 'bierbaum'),
					'ol'	=> esc_html__('Ordered', 'bierbaum'),
					'iconed'=> esc_html__('Iconed', 'bierbaum')
				),
				'yes_no'	=> bierbaum_get_list_yesno(),
				'on_off'	=> bierbaum_get_list_onoff(),
				'dir' 		=> bierbaum_get_list_directions(),
				'align'		=> bierbaum_get_list_alignments(),
				'float'		=> bierbaum_get_list_floats(),
				'show_hide'	=> bierbaum_get_list_showhide(),
				'sorting' 	=> bierbaum_get_list_sortings(),
				'ordering' 	=> bierbaum_get_list_orderings(),
				'shapes'	=> bierbaum_get_list_shapes(),
				'sizes'		=> bierbaum_get_list_sizes(),
				'sliders'	=> bierbaum_get_list_sliders(),
				'categories'=> bierbaum_get_list_categories(),
				'columns'	=> bierbaum_get_list_columns(),
				'images'	=> array_merge(array('none'=>"none"), bierbaum_get_list_files("images/icons", "png")),
				'icons'		=> array_merge(array("inherit", "none"), bierbaum_get_list_icons()),
				'locations'	=> bierbaum_get_list_dedicated_locations(),
				'filters'	=> bierbaum_get_list_portfolio_filters(),
				'formats'	=> bierbaum_get_list_post_formats_filters(),
				'hovers'	=> bierbaum_get_list_hovers(true),
				'hovers_dir'=> bierbaum_get_list_hovers_directions(true),
				'schemes'	=> bierbaum_get_list_color_schemes(true),
				'animations'		=> bierbaum_get_list_animations_in(),
				'margins' 			=> bierbaum_get_list_margins(true),
				'blogger_styles'	=> bierbaum_get_list_templates_blogger(),
				'forms'				=> bierbaum_get_list_templates_forms(),
				'posts_types'		=> bierbaum_get_list_posts_types(),
				'googlemap_styles'	=> bierbaum_get_list_googlemap_styles(),
				'field_types'		=> bierbaum_get_list_field_types(),
				'label_positions'	=> bierbaum_get_list_label_positions()
			);

			$BIERBAUM_GLOBALS['sc_params']['animation'] = array(
				"title" => esc_html__("Animation",  'bierbaum'),
				"desc" => wp_kses( __('Select animation while object enter in the visible area of page',  'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
				"value" => "none",
				"type" => "select",
				"options" => $BIERBAUM_GLOBALS['sc_params']['animations']
			);
			$BIERBAUM_GLOBALS['sc_params']['top'] = array(
				"title" => esc_html__("Top margin",  'bierbaum'),
				"divider" => true,
				"value" => "inherit",
				"type" => "select",
				"options" => $BIERBAUM_GLOBALS['sc_params']['margins']
			);
			$BIERBAUM_GLOBALS['sc_params']['bottom'] = array(
				"title" => esc_html__("Bottom margin",  'bierbaum'),
				"value" => "inherit",
				"type" => "select",
				"options" => $BIERBAUM_GLOBALS['sc_params']['margins']
			);
			$BIERBAUM_GLOBALS['sc_params']['left'] = array(
				"title" => esc_html__("Left margin",  'bierbaum'),
				"value" => "inherit",
				"type" => "select",
				"options" => $BIERBAUM_GLOBALS['sc_params']['margins']
			);
			$BIERBAUM_GLOBALS['sc_params']['right'] = array(
				"title" => esc_html__("Right margin",  'bierbaum'),
				"desc" => wp_kses( __("Margins around this shortcode", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
				"value" => "inherit",
				"type" => "select",
				"options" => $BIERBAUM_GLOBALS['sc_params']['margins']
			);

			$BIERBAUM_GLOBALS['sc_params'] = apply_filters('bierbaum_filter_shortcodes_params', $BIERBAUM_GLOBALS['sc_params']);

	
			// Shortcodes list
			//------------------------------------------------------------------
			$BIERBAUM_GLOBALS['shortcodes'] = array();
			
			// Add shortcodes
			do_action('bierbaum_action_shortcodes_list');

			// Sort shortcodes list
			uasort($BIERBAUM_GLOBALS['shortcodes'], function($a, $b) {
				return strcmp($a['title'], $b['title']);
			});
		}
	}
}
?>