<?php
/**
 * BierBaum Framework
 *
 * @package bierbaum
 * @since bierbaum 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Framework directory path from theme root
if ( ! defined( 'BIERBAUM_FW_DIR' ) )		define( 'BIERBAUM_FW_DIR', '/fw/' );

// Theme timing
if ( ! defined( 'BIERBAUM_START_TIME' ) )	define( 'BIERBAUM_START_TIME', microtime());			// Framework start time
if ( ! defined( 'BIERBAUM_START_MEMORY' ) )	define( 'BIERBAUM_START_MEMORY', memory_get_usage());	// Memory usage before core loading

// Global variables storage
if(true) {
	global $BIERBAUM_GLOBALS;
}

$BIERBAUM_GLOBALS = array(
	'theme_slug'	=> 'bierbaum',	// Theme slug (used as prefix for theme's functions, text domain, global variables, etc.)
	'page_template'	=> '',			// Storage for current page template name (used in the inheritance system)
    'allowed_tags'	=> array(		// Allowed tags list (with attributes) in translations
    	'p' => array(),
    	'br' => array(),
    	'b' => array(),
    	'strong' => array(),
    	'i' => array(),
    	'em' => array(),
    	'u' => array(),
    	'a' => array(
			'href' => array(),
			'title' => array(),
			'target' => array(),
			'id' => array(),
			'class' => array()
		),
    	'span' => array(
			'id' => array(),
			'class' => array()
		)
    )	
);

/* Theme setup section
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_loader_theme_setup' ) ) {
	add_action( 'after_setup_theme', 'bierbaum_loader_theme_setup', 20 );
	function bierbaum_loader_theme_setup() {
		
		// Init admin url and nonce
		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['admin_url']	= get_admin_url();
		$BIERBAUM_GLOBALS['admin_nonce']= wp_create_nonce($BIERBAUM_GLOBALS['admin_url']);
		$BIERBAUM_GLOBALS['ajax_url']	= admin_url('admin-ajax.php');
		$BIERBAUM_GLOBALS['ajax_nonce']	= wp_create_nonce($BIERBAUM_GLOBALS['ajax_url']);

		// Before init theme
		do_action('bierbaum_action_before_init_theme');

		// Load current values for main theme options
		bierbaum_load_main_options();

		// Theme core init - only for admin side. In frontend it called from header.php
		if ( is_admin() ) {
			bierbaum_core_init_theme();
		}
	}
}


/* Include core parts
------------------------------------------------------------------------ */

// Manual load important libraries before load all rest files
// core.strings must be first - we use bierbaum_str...() in the bierbaum_get_file_dir()
require_once (file_exists(get_stylesheet_directory().(BIERBAUM_FW_DIR).'core/core.strings.php') ? get_stylesheet_directory() : get_template_directory()).(BIERBAUM_FW_DIR).'core/core.strings.php';
// core.files must be first - we use bierbaum_get_file_dir() to include all rest parts
require_once (file_exists(get_stylesheet_directory().(BIERBAUM_FW_DIR).'core/core.files.php') ? get_stylesheet_directory() : get_template_directory()).(BIERBAUM_FW_DIR).'core/core.files.php';

// Include custom theme files
bierbaum_autoload_folder( 'includes' );

// Include core files
bierbaum_autoload_folder( 'core' );

// Include theme-specific plugins and post types
bierbaum_autoload_folder( 'plugins' );

// Include theme templates
bierbaum_autoload_folder( 'templates' );

// Include theme widgets
bierbaum_autoload_folder( 'widgets' );
?>