<?php
/**
 * The Header for our theme.
 */




// Theme init - don't remove next row! Load custom options
bierbaum_core_init_theme();




$body_scheme = bierbaum_get_custom_option('body_scheme');
if (empty($body_scheme)  || bierbaum_is_inherit_option($body_scheme)) $body_scheme = 'original';

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="<?php echo esc_attr('scheme_'.$body_scheme); ?>">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>" />
	<meta name="viewport" content="width=device-width, initial-scale=1<?php if (bierbaum_get_theme_option('responsive_layouts')=='yes') echo ', maximum-scale=1'; ?>">
	
	<?php
	if (floatval(get_bloginfo('version')) < 4.1) {
		?><title><?php wp_title( '|', true, 'right' ); ?></title><?php
	}
	?>

	<link rel="profile" href="http://gmpg.org/xfn/11" />
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
    
    <?php
	wp_head();
	?>
</head>

<body <?php body_class();?> >
	<?php echo force_balance_tags(bierbaum_get_custom_option('gtm_code')); ?>

	<?php do_action( 'before' ); ?>

	<?php
	// Add TOC items 'Home' and "To top"
	if (bierbaum_get_custom_option('menu_toc_home')=='yes')
		echo trim(bierbaum_sc_anchor(array(
			'id' => "toc_home",
			'title' => esc_html__('Home', 'bierbaum'),
			'description' => esc_html__('{{Return to Home}} - ||navigate to home page of the site', 'bierbaum'),
			'icon' => "icon-home",
			'separator' => "yes",
			'url' => esc_url(home_url('/'))
			)
		)); 
	if (bierbaum_get_custom_option('menu_toc_top')=='yes')
		echo trim(bierbaum_sc_anchor(array(
			'id' => "toc_top",
			'title' => esc_html__('To Top', 'bierbaum'),
			'description' => esc_html__('{{Back to top}} - ||scroll to top of the page', 'bierbaum'),
			'icon' => "icon-double-up",
			'separator' => "yes")
			)); 
	?>

	<?php if ( !bierbaum_param_is_off(bierbaum_get_custom_option('show_sidebar_outer')) ) { ?>
	<div class="outer_wrap">
	<?php } ?>

	<?php require_once bierbaum_get_file_dir('sidebar_outer.php'); ?>

	<?php
		$body_style  = bierbaum_get_custom_option('body_style');
		$class = $style = '';
		if ($body_style=='boxed' || bierbaum_get_custom_option('bg_image_load')=='always') {
			if (($img = (int) bierbaum_get_custom_option('bg_image', 0)) > 0)
				$class = 'bg_image_'.($img);
			else if (($img = (int) bierbaum_get_custom_option('bg_pattern', 0)) > 0)
				$class = 'bg_pattern_'.($img);
			else if (($img = bierbaum_get_custom_option('bg_color', '')) != '')
				$style = 'background-color: '.($img).';';
			else if (bierbaum_get_custom_option('bg_custom')=='yes') {
				if (($img = bierbaum_get_custom_option('bg_image_custom')) != '')
					$style = 'background: url('.esc_url($img).') ' . str_replace('_', ' ', bierbaum_get_custom_option('bg_image_custom_position')) . ' no-repeat fixed;';
				else if (($img = bierbaum_get_custom_option('bg_pattern_custom')) != '')
					$style = 'background: url('.esc_url($img).') 0 0 repeat fixed;';
				else if (($img = bierbaum_get_custom_option('bg_image')) > 0)
					$class = 'bg_image_'.($img);
				else if (($img = bierbaum_get_custom_option('bg_pattern')) > 0)
					$class = 'bg_pattern_'.($img);
				if (($img = bierbaum_get_custom_option('bg_color')) != '')
					$style .= 'background-color: '.($img).';';
			}
		}
	?>

	<div class="body_wrap<?php echo !empty($class) ? ' '.esc_attr($class) : ''; ?>"<?php echo !empty($style) ? ' style="'.esc_attr($style).'"' : ''; ?>>

		<?php
		$video_bg_show  = bierbaum_get_custom_option('show_video_bg')=='yes' && (bierbaum_get_custom_option('video_bg_youtube_code')!='' || bierbaum_get_custom_option('video_bg_url')!='');
		if ($video_bg_show) {
			$youtube = bierbaum_get_custom_option('video_bg_youtube_code');
			$video   = bierbaum_get_custom_option('video_bg_url');
			$overlay = bierbaum_get_custom_option('video_bg_overlay')=='yes';
			if (!empty($youtube)) {
				?>
				<div class="video_bg<?php echo !empty($overlay) ? ' video_bg_overlay' : ''; ?>" data-youtube-code="<?php echo esc_attr($youtube); ?>"></div>
				<?php
			} else if (!empty($video)) {
				$info = pathinfo($video);
				$ext = !empty($info['extension']) ? $info['extension'] : 'src';
				?>
				<div class="video_bg<?php echo !empty($overlay) ? ' video_bg_overlay' : ''; ?>"><video class="video_bg_tag" width="1280" height="720" data-width="1280" data-height="720" data-ratio="16:9" preload="metadata" autoplay loop src="<?php echo esc_url($video); ?>"><source src="<?php echo esc_url($video); ?>" type="video/<?php echo esc_attr($ext); ?>"></source></video></div>
				<?php
			}
		}
		?>

		<div class="page_wrap">

			<?php
			$top_panel_style = bierbaum_get_custom_option('top_panel_style');
			$top_panel_scheme = bierbaum_get_custom_option('top_panel_scheme');
			$top_panel_position = bierbaum_get_custom_option('top_panel_position');
			// Top panel 'Above' or 'Over'
			if (in_array($top_panel_position, array('above', 'over'))) {
				bierbaum_show_post_layout(array(
					'layout' => $top_panel_style,
					'position' => $top_panel_position,
					'scheme' => $top_panel_scheme
					), false);
			}
			// Slider
			require_once bierbaum_get_file_dir('templates/headers/_parts/slider.php');
			// Top panel 'Below'
			if ($top_panel_position == 'below') {
				bierbaum_show_post_layout(array(
					'layout' => $top_panel_style,
					'position' => $top_panel_position,
					'scheme' => $top_panel_scheme
					), false);
			}

			// Top of page section: page title and breadcrumbs
			$show_title = bierbaum_get_custom_option('show_page_title')=='yes';
			$show_breadcrumbs = bierbaum_get_custom_option('show_breadcrumbs')=='yes';
			if ($show_title || $show_breadcrumbs) {
				?>
				<div class="top_panel_title top_panel_style_<?php echo esc_attr(str_replace('header_', '', $top_panel_style)); ?> <?php echo (!empty($show_title) ? ' title_present' : '') . (!empty($show_breadcrumbs) ? ' breadcrumbs_present' : ''); ?> scheme_<?php echo esc_attr($top_panel_scheme); ?>">
					<div class="top_panel_title_inner top_panel_inner_style_<?php echo esc_attr(str_replace('header_', '', $top_panel_style)); ?> <?php echo (!empty($show_title) ? ' title_present_inner' : '') . (!empty($show_breadcrumbs) ? ' breadcrumbs_present_inner' : ''); ?>">
						<div class="content_wrap">
							<?php if ($show_title) { ?>
								<h1 class="page_title"><?php echo strip_tags(bierbaum_get_blog_title()); ?></h1>
							<?php } ?>
							<?php if ($show_breadcrumbs) { ?>
								<div class="breadcrumbs">
									<?php if (!is_404()) bierbaum_show_breadcrumbs(); ?>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
				<?php
			}
			?>

			<div class="page_content_wrap page_paddings_<?php echo esc_attr(bierbaum_get_custom_option('body_paddings')); ?>">

				<?php

				// Content and sidebar wrapper
				if ($body_style!='fullscreen') bierbaum_open_wrapper('<div class="content_wrap">');
				
				// Main content wrapper
				bierbaum_open_wrapper('<div class="content">');
				?>