<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('bierbaum_revslider_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_revslider_theme_setup', 1 );
	function bierbaum_revslider_theme_setup() {
		if (bierbaum_exists_revslider()) {
			add_filter( 'bierbaum_filter_list_sliders',					'bierbaum_revslider_list_sliders' );
			add_filter( 'bierbaum_filter_shortcodes_params',			'bierbaum_revslider_shortcodes_params' );
			add_filter( 'bierbaum_filter_theme_options_params',			'bierbaum_revslider_theme_options_params' );
			if (is_admin()) {
				add_filter( 'bierbaum_filter_importer_options',			'bierbaum_revslider_importer_set_options' );
				add_action( 'bierbaum_action_importer_params',			'bierbaum_revslider_importer_show_params', 10, 1 );
				add_action( 'bierbaum_action_importer_clear_tables',	'bierbaum_revslider_importer_clear_tables', 10, 2 );
				add_action( 'bierbaum_action_importer_import',			'bierbaum_revslider_importer_import', 10, 2 );
				add_action( 'bierbaum_action_importer_import_fields',	'bierbaum_revslider_importer_import_fields', 10, 1 );
			}
		}
		if (is_admin()) {
			add_filter( 'bierbaum_filter_importer_required_plugins',	'bierbaum_revslider_importer_required_plugins' );
			add_filter( 'bierbaum_filter_required_plugins',				'bierbaum_revslider_required_plugins' );
		}
	}
}

if ( !function_exists( 'bierbaum_revslider_settings_theme_setup2' ) ) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_revslider_settings_theme_setup2', 3 );
	function bierbaum_revslider_settings_theme_setup2() {
		if (bierbaum_exists_revslider()) {

			// Add Revslider specific options in the Theme Options
			global $BIERBAUM_GLOBALS;

			bierbaum_array_insert_after($BIERBAUM_GLOBALS['options'], 'slider_engine', array(
		
				"slider_alias" => array(
					"title" => esc_html__('Revolution Slider: Select slider',  'bierbaum'),
					"desc" => wp_kses( __("Select slider to show (if engine=revo in the field above)", 'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"override" => "category,services_group,page",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('revo')
					),
					"std" => "",
					"options" => $BIERBAUM_GLOBALS['options_params']['list_revo_sliders'],
					"type" => "select")
				
				)
			);

		}
	}
}

// Check if RevSlider installed and activated
if ( !function_exists( 'bierbaum_exists_revslider' ) ) {
	function bierbaum_exists_revslider() {
		return function_exists('rev_slider_shortcode');
		//return class_exists('RevSliderFront');
		//return is_plugin_active('revslider/revslider.php');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'bierbaum_revslider_required_plugins' ) ) {
	//add_filter('bierbaum_filter_required_plugins',	'bierbaum_revslider_required_plugins');
	function bierbaum_revslider_required_plugins($list=array()) {
	    global $BIERBAUM_GLOBALS;
		if (in_array('revslider', $BIERBAUM_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Revolution Slider',
					'slug' 		=> 'revslider',
					'source'	=> bierbaum_get_file_dir('plugins/install/revslider.dat'),
					'required' 	=> false
				);

		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check RevSlider in the required plugins
if ( !function_exists( 'bierbaum_revslider_importer_required_plugins' ) ) {
	//add_filter( 'bierbaum_filter_importer_required_plugins',	'bierbaum_revslider_importer_required_plugins' );
	function bierbaum_revslider_importer_required_plugins($not_installed='') {
	    global $BIERBAUM_GLOBALS;
		if (in_array('revslider', $BIERBAUM_GLOBALS['required_plugins']) && !bierbaum_exists_revslider() )
			$not_installed .= '<br>Revolution Slider';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'bierbaum_revslider_importer_set_options' ) ) {
	//add_filter( 'bierbaum_filter_importer_options',	'bierbaum_revslider_importer_set_options', 10, 1 );
	function bierbaum_revslider_importer_set_options($options=array()) {
	    global $BIERBAUM_GLOBALS;
		if ( in_array('revslider', $BIERBAUM_GLOBALS['required_plugins']) && bierbaum_exists_revslider() ) {
			$options['folder_with_revsliders'] = 'demo/revslider';			// Name of the folder with Revolution slider data
			$options['import_sliders'] = true;								// Import Revolution Sliders
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'bierbaum_revslider_importer_show_params' ) ) {
	//add_action( 'bierbaum_action_importer_params',	'bierbaum_revslider_importer_show_params', 10, 1 );
	function bierbaum_revslider_importer_show_params($importer) {
		global $BIERBAUM_GLOBALS;
		?>
		<input type="checkbox" <?php echo in_array('revslider', $BIERBAUM_GLOBALS['required_plugins']) ? 'checked="checked"' : ''; ?> value="1" name="import_revslider" id="import_revslider" /> <label for="import_revslider"><?php esc_html_e('Import Revolution Sliders', 'bierbaum'); ?></label><br>
		<?php
	}
}

// Clear tables
if ( !function_exists( 'bierbaum_revslider_importer_clear_tables' ) ) {
	//add_action( 'bierbaum_action_importer_clear_tables',	'bierbaum_revslider_importer_clear_tables', 10, 2 );
	function bierbaum_revslider_importer_clear_tables($importer, $clear_tables) {
		if (bierbaum_strpos($clear_tables, 'revslider')!==false && $importer->last_slider==0) {
			if ($importer->options['debug']) dfl(esc_html__('Clear Revolution Slider tables', 'bierbaum'));
			global $wpdb;
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_sliders");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_sliders".', 'bierbaum' ) . ' ' . ($res->get_error_message()) );
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_slides");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_slides".', 'bierbaum' ) . ' ' . ($res->get_error_message()) );
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_static_slides");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_static_slides".', 'bierbaum' ) . ' ' . ($res->get_error_message()) );
		}
	}
}

// Import posts
if ( !function_exists( 'bierbaum_revslider_importer_import' ) ) {
	//add_action( 'bierbaum_action_importer_import',	'bierbaum_revslider_importer_import', 10, 2 );
	function bierbaum_revslider_importer_import($importer, $action) {
		if ( $action == 'import_revslider' ) {
			if (file_exists(WP_PLUGIN_DIR.'/revslider/revslider.php')) {
				require_once WP_PLUGIN_DIR.'/revslider/revslider.php';
				$dir = bierbaum_get_folder_dir($importer->options['folder_with_revsliders']);
				if ( is_dir($dir) ) {
					$hdir = @opendir( $dir );
					if ( $hdir ) {
						if ($importer->options['debug']) dfl( esc_html__('Import Revolution sliders', 'bierbaum') );
						// Collect files with sliders
						$sliders = array();
						while (($file = readdir( $hdir ) ) !== false ) {
							$pi = pathinfo( ($dir) . '/' . ($file) );
							if ( substr($file, 0, 1) == '.' || is_dir( ($dir) . '/' . ($file) ) || $pi['extension']!='dat' )
								continue;
							$sliders[] = array('name' => $file, 'path' => ($dir) . '/' . ($file));
						}
						@closedir( $hdir );
						// Process next slider
						$slider = new RevSlider();
						for ($i=0; $i<count($sliders); $i++) {
							if ($i+1 <= $importer->last_slider) continue;
							if ($importer->options['debug']) dfl( sprintf(esc_html__('Process slider "%s"', 'bierbaum'), $sliders[$i]['name']) );
							if (!is_array($_FILES)) $_FILES = array();
							$_FILES["import_file"] = array("tmp_name" => $sliders[$i]['path']);
							$response = $slider->importSliderFromPost();
							if ($response["success"] == false) {
								$msg = sprintf(esc_html__('Revolution Slider "%s" import error', 'bierbaum'), $sliders[$i]['name']);
								$importer->response['error'] = $msg;
								dfl( $msg );
								dfo( $response );
							} else {
								if ($importer->options['debug']) dfl( sprintf(esc_html__('Slider "%s" imported', 'bierbaum'), $sliders[$i]['name']) );
							}
							break;
						}
						// Write last slider into log
						bierbaum_fpc($importer->import_log, $i+1 < count($sliders) ? '0|100|'.($i+1) : '');
						$importer->response['result'] = min(100, round(($i+1) / count($sliders) * 100));
					}
				}
			} else {
				dfl( sprintf(esc_html__('Can not locate plugin Revolution Slider: %s', 'bierbaum'), WP_PLUGIN_DIR.'/revslider/revslider.php') );
			}
		}
	}
}

// Display import progress
if ( !function_exists( 'bierbaum_revslider_importer_import_fields' ) ) {
	//add_action( 'bierbaum_action_importer_import_fields',	'bierbaum_revslider_importer_import_fields', 10, 1 );
	function bierbaum_revslider_importer_import_fields($importer) {
		?>
		<tr class="import_revslider">
			<td class="import_progress_item"><?php esc_html_e('Revolution Slider', 'bierbaum'); ?></td>
			<td class="import_progress_status"></td>
		</tr>
		<?php
	}
}


// Lists
//------------------------------------------------------------------------

// Add RevSlider in the sliders list, prepended inherit (if need)
if ( !function_exists( 'bierbaum_revslider_list_sliders' ) ) {
	//add_filter( 'bierbaum_filter_list_sliders',					'bierbaum_revslider_list_sliders' );
	function bierbaum_revslider_list_sliders($list=array()) {
		$list["revo"] = esc_html__("Layer slider (Revolution)", 'bierbaum');
		return $list;
	}
}

// Return Revo Sliders list, prepended inherit (if need)
if ( !function_exists( 'bierbaum_get_list_revo_sliders' ) ) {
	function bierbaum_get_list_revo_sliders($prepend_inherit=false) {
		global $BIERBAUM_GLOBALS;
		if (isset($BIERBAUM_GLOBALS['list_revo_sliders']))
			$list = $BIERBAUM_GLOBALS['list_revo_sliders'];
		else {
			$list = array();
			if (bierbaum_exists_revslider()) {
				global $wpdb;
				$rows = $wpdb->get_results( "SELECT alias, title FROM " . esc_sql($wpdb->prefix) . "revslider_sliders" );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->alias] = $row->title;
					}
				}
			}
			$BIERBAUM_GLOBALS['list_revo_sliders'] = $list = apply_filters('bierbaum_filter_list_revo_sliders', $list);
		}
		return $prepend_inherit ? bierbaum_array_merge(array('inherit' => esc_html__("Inherit", 'bierbaum')), $list) : $list;
	}
}

// Add RevSlider in the shortcodes params
if ( !function_exists( 'bierbaum_revslider_shortcodes_params' ) ) {
	//add_filter( 'bierbaum_filter_shortcodes_params',			'bierbaum_revslider_shortcodes_params' );
	function bierbaum_revslider_shortcodes_params($list=array()) {
		$list["revo_sliders"] = bierbaum_get_list_revo_sliders();
		return $list;
	}
}

// Add RevSlider in the Theme Options params
if ( !function_exists( 'bierbaum_revslider_theme_options_params' ) ) {
	//add_filter( 'bierbaum_filter_theme_options_params',			'bierbaum_revslider_theme_options_params' );
	function bierbaum_revslider_theme_options_params($list=array()) {
		global $BIERBAUM_GLOBALS;
		$list["list_revo_sliders"] = array('$'.$BIERBAUM_GLOBALS['theme_slug'].'_get_list_revo_sliders' => '');
		return $list;
	}
}
?>