<?php
/* Visual Composer support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('bierbaum_vc_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_vc_theme_setup', 1 );
	function bierbaum_vc_theme_setup() {
		if (bierbaum_exists_visual_composer()) {
			if (is_admin()) {
				add_filter( 'bierbaum_filter_importer_options',				'bierbaum_vc_importer_set_options' );
			}
		}
		if (is_admin()) {
			add_filter( 'bierbaum_filter_importer_required_plugins',		'bierbaum_vc_importer_required_plugins' );
			add_filter( 'bierbaum_filter_required_plugins',					'bierbaum_vc_required_plugins' );
		}
	}
}

// Check if Visual Composer installed and activated
if ( !function_exists( 'bierbaum_exists_visual_composer' ) ) {
	function bierbaum_exists_visual_composer() {
		return class_exists('Vc_Manager');
	}
}

// Check if Visual Composer in frontend editor mode
if ( !function_exists( 'bierbaum_vc_is_frontend' ) ) {
	function bierbaum_vc_is_frontend() {
		return (isset($_GET['vc_editable']) && $_GET['vc_editable']=='true')
			|| (isset($_GET['vc_action']) && $_GET['vc_action']=='vc_inline');
		//return function_exists('vc_is_frontend_editor') && vc_is_frontend_editor();
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'bierbaum_vc_required_plugins' ) ) {
	//add_filter('bierbaum_filter_required_plugins',	'bierbaum_vc_required_plugins');
	function bierbaum_vc_required_plugins($list=array()) {
	    global $BIERBAUM_GLOBALS;
		if (in_array('visual_composer', $BIERBAUM_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Visual Composer',
					'slug' 		=> 'js_composer',
					'source'	=> bierbaum_get_file_dir('plugins/install/js_composer.dat'),
					'required' 	=> false
				);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check VC in the required plugins
if ( !function_exists( 'bierbaum_vc_importer_required_plugins' ) ) {
	//add_filter( 'bierbaum_filter_importer_required_plugins',	'bierbaum_vc_importer_required_plugins' );
	function bierbaum_vc_importer_required_plugins($not_installed='') {
	    global $BIERBAUM_GLOBALS;
		if (in_array('visual_composer', $BIERBAUM_GLOBALS['required_plugins']) && !bierbaum_exists_visual_composer() && $_POST['data_type']=='vc' )
			$not_installed .= '<br>Visual Composer';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'bierbaum_vc_importer_set_options' ) ) {
	//add_filter( 'bierbaum_filter_importer_options',	'bierbaum_vc_importer_set_options' );
	function bierbaum_vc_importer_set_options($options=array()) {
	    global $BIERBAUM_GLOBALS;
		if ( in_array('visual_composer', $BIERBAUM_GLOBALS['required_plugins']) && bierbaum_exists_visual_composer() ) {
			$options['additional_options'][] = 'wpb_js_templates';		// Add slugs to export options for this plugin

		}
		return $options;
	}
}
?>