<?php
/**
 * BierBaum Framework: Testimonial post type settings
 *
 * @package	bierbaum
 * @since	bierbaum 1.0
 */

// Theme init
if (!function_exists('bierbaum_testimonial_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_testimonial_theme_setup', 1 );
	function bierbaum_testimonial_theme_setup() {
	
		// Add item in the admin menu
		add_action('add_meta_boxes',		'bierbaum_testimonial_add_meta_box');

		// Save data from meta box
		add_action('save_post',				'bierbaum_testimonial_save_data');

		// Add shortcodes [trx_testimonials] and [trx_testimonials_item]
		add_action('bierbaum_action_shortcodes_list',		'bierbaum_testimonials_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_testimonials_reg_shortcodes_vc');

		// Meta box fields
		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['testimonial_meta_box'] = array(
			'id' => 'testimonial-meta-box',
			'title' => esc_html__('Testimonial Details', 'bierbaum'),
			'page' => 'testimonial',
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(
				"testimonial_author" => array(
					"title" => esc_html__('Testimonial author',  'bierbaum'),
					"desc" => wp_kses( __("Name of the testimonial's author", 'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_author",
					"std" => "",
					"type" => "text"),
				"testimonial_position" => array(
					"title" => esc_html__("Author's position",  'bierbaum'),
					"desc" => wp_kses( __("Position of the testimonial's author", 'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_author",
					"std" => "",
					"type" => "text"),
				"testimonial_email" => array(
					"title" => esc_html__("Author's e-mail",  'bierbaum'),
					"desc" => wp_kses( __("E-mail of the testimonial's author - need to take Gravatar (if registered)", 'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_email",
					"std" => "",
					"type" => "text"),
				"testimonial_link" => array(
					"title" => esc_html__('Testimonial link',  'bierbaum'),
					"desc" => wp_kses( __("URL of the testimonial source or author profile page", 'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_link",
					"std" => "",
					"type" => "text")
			)
		);
		
		// Add supported data types
		bierbaum_theme_support_pt('testimonial');
		bierbaum_theme_support_tx('testimonial_group');
		
	}
}


// Add meta box
if (!function_exists('bierbaum_testimonial_add_meta_box')) {
	//add_action('add_meta_boxes', 'bierbaum_testimonial_add_meta_box');
	function bierbaum_testimonial_add_meta_box() {
		global $BIERBAUM_GLOBALS;
		$mb = $BIERBAUM_GLOBALS['testimonial_meta_box'];
		add_meta_box($mb['id'], $mb['title'], 'bierbaum_testimonial_show_meta_box', $mb['page'], $mb['context'], $mb['priority']);
	}
}

// Callback function to show fields in meta box
if (!function_exists('bierbaum_testimonial_show_meta_box')) {
	function bierbaum_testimonial_show_meta_box() {
		global $post, $BIERBAUM_GLOBALS;

		// Use nonce for verification
		echo '<input type="hidden" name="meta_box_testimonial_nonce" value="', esc_attr($BIERBAUM_GLOBALS['admin_nonce']), '" />';
		
		$data = get_post_meta($post->ID, 'bierbaum_testimonial_data', true);
	
		$fields = $BIERBAUM_GLOBALS['testimonial_meta_box']['fields'];
		?>
		<table class="testimonial_area">
		<?php
		if (is_array($fields) && count($fields) > 0) {
			foreach ($fields as $id=>$field) { 
				$meta = isset($data[$id]) ? $data[$id] : '';
				?>
				<tr class="testimonial_field <?php echo esc_attr($field['class']); ?>" valign="top">
					<td><label for="<?php echo esc_attr($id); ?>"><?php echo esc_attr($field['title']); ?></label></td>
					<td><input type="text" name="<?php echo esc_attr($id); ?>" id="<?php echo esc_attr($id); ?>" value="<?php echo esc_attr($meta); ?>" size="30" />
						<br><small><?php echo esc_attr($field['desc']); ?></small></td>
				</tr>
				<?php
			}
		}
		?>
		</table>
		<?php
	}
}


// Save data from meta box
if (!function_exists('bierbaum_testimonial_save_data')) {
	//add_action('save_post', 'bierbaum_testimonial_save_data');
	function bierbaum_testimonial_save_data($post_id) {
		global $BIERBAUM_GLOBALS;
		// verify nonce
		if (!isset($_POST['meta_box_testimonial_nonce']) || !wp_verify_nonce($_POST['meta_box_testimonial_nonce'], $BIERBAUM_GLOBALS['admin_url'])) {
			return $post_id;
		}

		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post_id;
		}

		// check permissions
		if ($_POST['post_type']!='testimonial' || !current_user_can('edit_post', $post_id)) {
			return $post_id;
		}

		$data = array();

		$fields = $BIERBAUM_GLOBALS['testimonial_meta_box']['fields'];

		// Post type specific data handling
		if (is_array($fields) && count($fields) > 0) {
			foreach ($fields as $id=>$field) { 
				if (isset($_POST[$id])) 
					$data[$id] = stripslashes($_POST[$id]);
			}
		}

		update_post_meta($post_id, 'bierbaum_testimonial_data', $data);
	}
}






// ---------------------------------- [trx_testimonials] ---------------------------------------

/*
[trx_testimonials id="unique_id" style="1|2|3"]
	[trx_testimonials_item user="user_login"]Testimonials text[/trx_testimonials_item]
	[trx_testimonials_item email="" name="" position="" photo="photo_url"]Testimonials text[/trx_testimonials]
[/trx_testimonials]
*/

if (!function_exists('bierbaum_sc_testimonials')) {
	function bierbaum_sc_testimonials($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"style" => "testimonials-1",
			"columns" => 1,
			"slider" => "yes",
			"slides_space" => 0,
			"controls" => "no",
			"interval" => "",
			"autoheight" => "no",
			"align" => "",
			"custom" => "no",
			"ids" => "",
			"cat" => "",
			"count" => "3",
			"offset" => "",
			"orderby" => "date",
			"order" => "desc",
			"scheme" => "",
			"bg_color" => "",
			"bg_image" => "",
			"bg_overlay" => "",
			"bg_texture" => "",
			"title" => "",
			"subtitle" => "",
			"description" => "",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"width" => "",
			"height" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
	
		if (empty($id)) $id = "sc_testimonials_".str_replace('.', '', mt_rand());
		if (empty($width)) $width = "100%";
		if (!empty($height) && bierbaum_param_is_on($autoheight)) $autoheight = "no";
		if (empty($interval)) $interval = mt_rand(5000, 10000);
	
		if ($bg_image > 0) {
			$attach = wp_get_attachment_image_src( $bg_image, 'full' );
			if (isset($attach[0]) && $attach[0]!='')
				$bg_image = $attach[0];
		}
	
		if ($bg_overlay > 0) {
			if ($bg_color=='') $bg_color = bierbaum_get_scheme_color('bg');
			$rgb = bierbaum_hex2rgb($bg_color);
		}
		
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);

		$ws = bierbaum_get_css_dimensions_from_values($width);
		$hs = bierbaum_get_css_dimensions_from_values('', $height);
		$css .= ($hs) . ($ws);

		$count = max(1, (int) $count);
		$columns = max(1, min(12, (int) $columns));
		if (bierbaum_param_is_off($custom) && $count < $columns) $columns = $count;
		
		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['sc_testimonials_id'] = $id;
		$BIERBAUM_GLOBALS['sc_testimonials_style'] = $style;
		$BIERBAUM_GLOBALS['sc_testimonials_columns'] = $columns;
		$BIERBAUM_GLOBALS['sc_testimonials_counter'] = 0;
		$BIERBAUM_GLOBALS['sc_testimonials_slider'] = $slider;
		$BIERBAUM_GLOBALS['sc_testimonials_css_wh'] = $ws . $hs;

		if (bierbaum_param_is_on($slider)) bierbaum_enqueue_slider('swiper');
	
		$output = ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || bierbaum_strlen($bg_texture)>2 || ($scheme && !bierbaum_param_is_off($scheme) && !bierbaum_param_is_inherit($scheme))
					? '<div class="sc_testimonials_wrap sc_section'
							. ($scheme && !bierbaum_param_is_off($scheme) && !bierbaum_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '') 
							. '"'
						.' style="'
							. ($bg_color !== '' && $bg_overlay==0 ? 'background-color:' . esc_attr($bg_color) . ';' : '')
							. ($bg_image !== '' ? 'background-image:url(' . esc_url($bg_image) . ');' : '')
							. '"'
						. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
						. '>'
						. '<div class="sc_section_overlay'.($bg_texture>0 ? ' texture_bg_'.esc_attr($bg_texture) : '') . '"'
								. ' style="' . ($bg_overlay>0 ? 'background-color:rgba('.(int)$rgb['r'].','.(int)$rgb['g'].','.(int)$rgb['b'].','.min(1, max(0, $bg_overlay)).');' : '')
									. (bierbaum_strlen($bg_texture)>2 ? 'background-image:url('.esc_url($bg_texture).');' : '')
									. '"'
									. ($bg_overlay > 0 ? ' data-overlay="'.esc_attr($bg_overlay).'" data-bg_color="'.esc_attr($bg_color).'"' : '')
									. '>' 
					: '')
				. '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') 
				. ' class="sc_testimonials sc_testimonials_style_'.esc_attr($style)
 					. ' ' . esc_attr(bierbaum_get_template_property($style, 'container_classes'))
 					. (bierbaum_param_is_on($slider)
						? ' sc_slider_swiper swiper-slider-container'
							. ' ' . esc_attr(bierbaum_get_slider_controls_classes($controls))
							. (bierbaum_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
							. ($hs ? ' sc_slider_height_fixed' : '')
						: '')
					. (!empty($class) ? ' '.esc_attr($class) : '')
					. ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
					. '"'
				. ($bg_color=='' && $bg_image=='' && $bg_overlay==0 && ($bg_texture=='' || $bg_texture=='0') && !bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
				. (!empty($width) && bierbaum_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
				. (!empty($height) && bierbaum_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
				. ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
				. ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
				. ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
				. ($css!='' ? ' style="'.esc_attr($css).'"' : '')
			. '>'
			. (!empty($subtitle) ? '<h6 class="sc_testimonials_subtitle sc_item_subtitle">' . trim(bierbaum_strmacros($subtitle)) . '</h6>' : '')
			. (!empty($title) ? '<h2 class="sc_testimonials_title sc_item_title">' . trim(bierbaum_strmacros($title)) . '</h2>' : '')
			. (!empty($description) ? '<div class="sc_testimonials_descr sc_item_descr">' . trim(bierbaum_strmacros($description)) . '</div>' : '')
			. (bierbaum_param_is_on($slider) 
				? '<div class="slides swiper-wrapper">' 
				: ($columns > 1 
					? '<div class="sc_columns columns_wrap">' 
					: '')
				);
	
		$content = do_shortcode($content);
			
		if (bierbaum_param_is_on($custom) && $content) {
			$output .= $content;
		} else {
			global $post;
		
			if (!empty($ids)) {
				$posts = explode(',', $ids);
				$count = count($posts);
			}
			
			$args = array(
				'post_type' => 'testimonial',
				'post_status' => 'publish',
				'posts_per_page' => $count,
				'ignore_sticky_posts' => true,
				'order' => $order=='asc' ? 'asc' : 'desc',
			);
		
			if ($offset > 0 && empty($ids)) {
				$args['offset'] = $offset;
			}
		
			$args = bierbaum_query_add_sort_order($args, $orderby, $order);
			$args = bierbaum_query_add_posts_and_cats($args, $ids, 'testimonial', $cat, 'testimonial_group');
	
			$query = new WP_Query( $args );
	
			$post_number = 0;
				
			while ( $query->have_posts() ) { 
				$query->the_post();
				$post_number++;
				$args = array(
					'layout' => $style,
					'show' => false,
					'number' => $post_number,
					'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
					"descr" => bierbaum_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
					"orderby" => $orderby,
					'content' => false,
					'terms_list' => false,
					'columns_count' => $columns,
					'slider' => $slider,
					'tag_id' => $id ? $id . '_' . $post_number : '',
					'tag_class' => '',
					'tag_animation' => '',
					'tag_css' => '',
					'tag_css_wh' => $ws . $hs
				);
				$post_data = bierbaum_get_post_data($args);
				$post_data['post_content'] = wpautop($post_data['post_content']);	// Add <p> around text and paragraphs. Need separate call because 'content'=>false (see above)
				$post_meta = get_post_meta($post_data['post_id'], 'bierbaum_testimonial_data', true);
				$thumb_sizes = bierbaum_get_thumb_sizes(array('layout' => $style));
				$args['author'] = $post_meta['testimonial_author'];
				$args['position'] = $post_meta['testimonial_position'];
				$args['link'] = !empty($post_meta['testimonial_link']) ? $post_meta['testimonial_link'] : '';	//$post_data['post_link'];
				$args['email'] = $post_meta['testimonial_email'];
				$args['photo'] = $post_data['post_thumb'];
				$mult = bierbaum_get_retina_multiplier();
				if (empty($args['photo']) && !empty($args['email'])) $args['photo'] = get_avatar($args['email'], $thumb_sizes['w']*$mult);
				$output .= bierbaum_show_post_layout($args, $post_data);
			}
			wp_reset_postdata();
		}
	
		if (bierbaum_param_is_on($slider)) {
			$output .= '</div>'
				. '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
				. '<div class="sc_slider_pagination_wrap"></div>';
		} else if ($columns > 1) {
			$output .= '</div>';
		}

		$output .= '</div>'
					. ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || bierbaum_strlen($bg_texture)>2
						?  '</div></div>'
						: '');
	
		// Add template specific scripts and styles
		do_action('bierbaum_action_blog_scripts', $style);

		return apply_filters('bierbaum_shortcode_output', $output, 'trx_testimonials', $atts, $content);
	}
	bierbaum_require_shortcode('trx_testimonials', 'bierbaum_sc_testimonials');
}
	
	
if (!function_exists('bierbaum_sc_testimonials_item')) {
	function bierbaum_sc_testimonials_item($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"author" => "",
			"position" => "",
			"link" => "",
			"photo" => "",
			"email" => "",
			// Common params
			"id" => "",
			"class" => "",
			"css" => "",
		), $atts)));

		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['sc_testimonials_counter']++;
	
		$id = $id ? $id : ($BIERBAUM_GLOBALS['sc_testimonials_id'] ? $BIERBAUM_GLOBALS['sc_testimonials_id'] . '_' . $BIERBAUM_GLOBALS['sc_testimonials_counter'] : '');
	
		$thumb_sizes = bierbaum_get_thumb_sizes(array('layout' => $BIERBAUM_GLOBALS['sc_testimonials_style']));

		if (empty($photo)) {
			if (!empty($email))
				$mult = bierbaum_get_retina_multiplier();
				$photo = get_avatar($email, $thumb_sizes['w']*$mult);
		} else {
			if ($photo > 0) {
				$attach = wp_get_attachment_image_src( $photo, 'full' );
				if (isset($attach[0]) && $attach[0]!='')
					$photo = $attach[0];
			}
			$photo = bierbaum_get_resized_image_tag($photo, $thumb_sizes['w'], $thumb_sizes['h']);
		}

		$post_data = array(
			'post_content' => do_shortcode($content)
		);
		$args = array(
			'layout' => $BIERBAUM_GLOBALS['sc_testimonials_style'],
			'number' => $BIERBAUM_GLOBALS['sc_testimonials_counter'],
			'columns_count' => $BIERBAUM_GLOBALS['sc_testimonials_columns'],
			'slider' => $BIERBAUM_GLOBALS['sc_testimonials_slider'],
			'show' => false,
			'descr'  => 0,
			'tag_id' => $id,
			'tag_class' => $class,
			'tag_animation' => '',
			'tag_css' => $css,
			'tag_css_wh' => $BIERBAUM_GLOBALS['sc_testimonials_css_wh'],
			'author' => $author,
			'position' => $position,
			'link' => $link,
			'email' => $email,
			'photo' => $photo
		);
		$output = bierbaum_show_post_layout($args, $post_data);

		return apply_filters('bierbaum_shortcode_output', $output, 'trx_testimonials_item', $atts, $content);
	}
	bierbaum_require_shortcode('trx_testimonials_item', 'bierbaum_sc_testimonials_item');
}
// ---------------------------------- [/trx_testimonials] ---------------------------------------



// Add [trx_testimonials] and [trx_testimonials_item] in the shortcodes list
if (!function_exists('bierbaum_testimonials_reg_shortcodes')) {
	//add_filter('bierbaum_action_shortcodes_list',	'bierbaum_testimonials_reg_shortcodes');
	function bierbaum_testimonials_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
		if (isset($BIERBAUM_GLOBALS['shortcodes'])) {

			$testimonials_groups = bierbaum_get_list_terms(false, 'testimonial_group');
			$testimonials_styles = bierbaum_get_list_templates('testimonials');
			$controls = bierbaum_get_list_slider_controls();

			bierbaum_array_insert_before($BIERBAUM_GLOBALS['shortcodes'], 'trx_title', array(
			
				// Testimonials
				"trx_testimonials" => array(
					"title" => esc_html__("Testimonials", "bierbaum"),
					"desc" => wp_kses( __("Insert testimonials into post (page)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"title" => array(
							"title" => esc_html__("Title", "bierbaum"),
							"desc" => wp_kses( __("Title for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"subtitle" => array(
							"title" => esc_html__("Subtitle", "bierbaum"),
							"desc" => wp_kses( __("Subtitle for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"description" => array(
							"title" => esc_html__("Description", "bierbaum"),
							"desc" => wp_kses( __("Short description for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "textarea"
						),
						"style" => array(
							"title" => esc_html__("Testimonials style", "bierbaum"),
							"desc" => wp_kses( __("Select style to display testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "testimonials-1",
							"type" => "select",
							"options" => $testimonials_styles
						),
						"columns" => array(
							"title" => esc_html__("Columns", "bierbaum"),
							"desc" => wp_kses( __("How many columns use to show testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => 1,
							"min" => 1,
							"max" => 6,
							"step" => 1,
							"type" => "spinner"
						),
						"slider" => array(
							"title" => esc_html__("Slider", "bierbaum"),
							"desc" => wp_kses( __("Use slider to show testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "yes",
							"type" => "switch",
							"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no']
						),
						"controls" => array(
							"title" => esc_html__("Controls", "bierbaum"),
							"desc" => wp_kses( __("Slider controls style and position", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $controls
						),
						"slides_space" => array(
							"title" => esc_html__("Space between slides", "bierbaum"),
							"desc" => wp_kses( __("Size of space (in px) between slides", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 0,
							"min" => 0,
							"max" => 100,
							"step" => 10,
							"type" => "spinner"
						),
						"interval" => array(
							"title" => esc_html__("Slides change interval", "bierbaum"),
							"desc" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 7000,
							"step" => 500,
							"min" => 0,
							"type" => "spinner"
						),
						"autoheight" => array(
							"title" => esc_html__("Autoheight", "bierbaum"),
							"desc" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => "yes",
							"type" => "switch",
							"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no']
						),
						"align" => array(
							"title" => esc_html__("Alignment", "bierbaum"),
							"desc" => wp_kses( __("Alignment of the testimonials block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $BIERBAUM_GLOBALS['sc_params']['align']
						),
						"custom" => array(
							"title" => esc_html__("Custom", "bierbaum"),
							"desc" => wp_kses( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "no",
							"type" => "switch",
							"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no']
						),
						"cat" => array(
							"title" => esc_html__("Categories", "bierbaum"),
							"desc" => wp_kses( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"divider" => true,
							"value" => "",
							"type" => "select",
							"style" => "list",
							"multiple" => true,
							"options" => bierbaum_array_merge(array(0 => esc_html__('- Select category -', 'bierbaum')), $testimonials_groups)
						),
						"count" => array(
							"title" => esc_html__("Number of posts", "bierbaum"),
							"desc" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 3,
							"min" => 1,
							"max" => 100,
							"type" => "spinner"
						),
						"offset" => array(
							"title" => esc_html__("Offset before select posts", "bierbaum"),
							"desc" => wp_kses( __("Skip posts before select next part.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 0,
							"min" => 0,
							"type" => "spinner"
						),
						"orderby" => array(
							"title" => esc_html__("Post order by", "bierbaum"),
							"desc" => wp_kses( __("Select desired posts sorting method", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "date",
							"type" => "select",
							"options" => $BIERBAUM_GLOBALS['sc_params']['sorting']
						),
						"order" => array(
							"title" => esc_html__("Post order", "bierbaum"),
							"desc" => wp_kses( __("Select desired posts order", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "desc",
							"type" => "switch",
							"size" => "big",
							"options" => $BIERBAUM_GLOBALS['sc_params']['ordering']
						),
						"ids" => array(
							"title" => esc_html__("Post IDs list", "bierbaum"),
							"desc" => wp_kses( __("Comma separated list of posts ID. If set - parameters above are ignored!", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "",
							"type" => "text"
						),
						"scheme" => array(
							"title" => esc_html__("Color scheme", "bierbaum"),
							"desc" => wp_kses( __("Select color scheme for this block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "checklist",
							"options" => $BIERBAUM_GLOBALS['sc_params']['schemes']
						),
						"bg_color" => array(
							"title" => esc_html__("Background color", "bierbaum"),
							"desc" => wp_kses( __("Any background color for this section", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "color"
						),
						"bg_image" => array(
							"title" => esc_html__("Background image URL", "bierbaum"),
							"desc" => wp_kses( __("Select or upload image or write URL from other site for the background", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"readonly" => false,
							"value" => "",
							"type" => "media"
						),
						"bg_overlay" => array(
							"title" => esc_html__("Overlay", "bierbaum"),
							"desc" => wp_kses( __("Overlay color opacity (from 0.0 to 1.0)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"min" => "0",
							"max" => "1",
							"step" => "0.1",
							"value" => "0",
							"type" => "spinner"
						),
						"bg_texture" => array(
							"title" => esc_html__("Texture", "bierbaum"),
							"desc" => wp_kses( __("Predefined texture style from 1 to 11. 0 - without texture.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
							"min" => "0",
							"max" => "11",
							"step" => "1",
							"value" => "0",
							"type" => "spinner"
						),
						"width" => bierbaum_shortcodes_width(),
						"height" => bierbaum_shortcodes_height(),
						"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
						"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
						"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
						"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
						"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
						"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
						"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
						"css" => $BIERBAUM_GLOBALS['sc_params']['css']
					),
					"children" => array(
						"name" => "trx_testimonials_item",
						"title" => esc_html__("Item", "bierbaum"),
						"desc" => wp_kses( __("Testimonials item (custom parameters)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"container" => true,
						"params" => array(
							"author" => array(
								"title" => esc_html__("Author", "bierbaum"),
								"desc" => wp_kses( __("Name of the testimonmials author", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"link" => array(
								"title" => esc_html__("Link", "bierbaum"),
								"desc" => wp_kses( __("Link URL to the testimonmials author page", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"email" => array(
								"title" => esc_html__("E-mail", "bierbaum"),
								"desc" => wp_kses( __("E-mail of the testimonmials author (to get gravatar)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"photo" => array(
								"title" => esc_html__("Photo", "bierbaum"),
								"desc" => wp_kses( __("Select or upload photo of testimonmials author or write URL of photo from other site", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "media"
							),
							"_content_" => array(
								"title" => esc_html__("Testimonials text", "bierbaum"),
								"desc" => wp_kses( __("Current testimonials text", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
								"divider" => true,
								"rows" => 4,
								"value" => "",
								"type" => "textarea"
							),
							"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
							"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
							"css" => $BIERBAUM_GLOBALS['sc_params']['css']
						)
					)
				)

			));
		}
	}
}


// Add [trx_testimonials] and [trx_testimonials_item] in the VC shortcodes list
if (!function_exists('bierbaum_testimonials_reg_shortcodes_vc')) {
	//add_filter('bierbaum_action_shortcodes_list_vc',	'bierbaum_testimonials_reg_shortcodes_vc');
	function bierbaum_testimonials_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;

		$testimonials_groups = bierbaum_get_list_terms(false, 'testimonial_group');
		$testimonials_styles = bierbaum_get_list_templates('testimonials');
		$controls			 = bierbaum_get_list_slider_controls();
			
		// Testimonials			
		vc_map( array(
				"base" => "trx_testimonials",
				"name" => esc_html__("Testimonials", "bierbaum"),
				"description" => wp_kses( __("Insert testimonials slider", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('Content', 'bierbaum'),
				'icon' => 'icon_trx_testimonials',
				"class" => "trx_sc_columns trx_sc_testimonials",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_testimonials_item'),
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => esc_html__("Testimonials style", "bierbaum"),
						"description" => wp_kses( __("Select style to display testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"admin_label" => true,
						"value" => array_flip($testimonials_styles),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slider",
						"heading" => esc_html__("Slider", "bierbaum"),
						"description" => wp_kses( __("Use slider to show testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'bierbaum'),
						"class" => "",
						"std" => "yes",
						"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['yes_no']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "controls",
						"heading" => esc_html__("Controls", "bierbaum"),
						"description" => wp_kses( __("Slider controls style and position", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'bierbaum'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"std" => "no",
						"value" => array_flip($controls),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slides_space",
						"heading" => esc_html__("Space between slides", "bierbaum"),
						"description" => wp_kses( __("Size of space (in px) between slides", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'bierbaum'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "interval",
						"heading" => esc_html__("Slides change interval", "bierbaum"),
						"description" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'bierbaum'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "7000",
						"type" => "textfield"
					),
					array(
						"param_name" => "autoheight",
						"heading" => esc_html__("Autoheight", "bierbaum"),
						"description" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'bierbaum'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => array("Autoheight" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => esc_html__("Alignment", "bierbaum"),
						"description" => wp_kses( __("Alignment of the testimonials block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "custom",
						"heading" => esc_html__("Custom", "bierbaum"),
						"description" => wp_kses( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array("Custom slides" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", "bierbaum"),
						"description" => wp_kses( __("Title for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Captions', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => esc_html__("Subtitle", "bierbaum"),
						"description" => wp_kses( __("Subtitle for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => esc_html__("Description", "bierbaum"),
						"description" => wp_kses( __("Description for the block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "textarea"
					),
					array(
						"param_name" => "cat",
						"heading" => esc_html__("Categories", "bierbaum"),
						"description" => wp_kses( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip(bierbaum_array_merge(array(0 => esc_html__('- Select category -', 'bierbaum')), $testimonials_groups)),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", "bierbaum"),
						"description" => wp_kses( __("How many columns use to show testimonials", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => esc_html__("Number of posts", "bierbaum"),
						"description" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => esc_html__("Offset before select posts", "bierbaum"),
						"description" => wp_kses( __("Skip posts before select next part.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Post sorting", "bierbaum"),
						"description" => wp_kses( __("Select desired posts sorting method", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Post order", "bierbaum"),
						"description" => wp_kses( __("Select desired posts order", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("Post IDs list", "bierbaum"),
						"description" => wp_kses( __("Comma separated list of posts ID. If set - parameters above are ignored!", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'bierbaum'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "scheme",
						"heading" => esc_html__("Color scheme", "bierbaum"),
						"description" => wp_kses( __("Select color scheme for this block", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'bierbaum'),
						"class" => "",
						"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['schemes']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_color",
						"heading" => esc_html__("Background color", "bierbaum"),
						"description" => wp_kses( __("Any background color for this section", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => esc_html__("Background image URL", "bierbaum"),
						"description" => wp_kses( __("Select background image from library for this section", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_overlay",
						"heading" => esc_html__("Overlay", "bierbaum"),
						"description" => wp_kses( __("Overlay color opacity (from 0.0 to 1.0)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_texture",
						"heading" => esc_html__("Texture", "bierbaum"),
						"description" => wp_kses( __("Texture style from 1 to 11. Empty or 0 - without texture.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'bierbaum'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					bierbaum_vc_width(),
					bierbaum_vc_height(),
					$BIERBAUM_GLOBALS['vc_params']['margin_top'],
					$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
					$BIERBAUM_GLOBALS['vc_params']['margin_left'],
					$BIERBAUM_GLOBALS['vc_params']['margin_right'],
					$BIERBAUM_GLOBALS['vc_params']['id'],
					$BIERBAUM_GLOBALS['vc_params']['class'],
					$BIERBAUM_GLOBALS['vc_params']['animation'],
					$BIERBAUM_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnsView'
		) );
			
			
		vc_map( array(
				"base" => "trx_testimonials_item",
				"name" => esc_html__("Testimonial", "bierbaum"),
				"description" => wp_kses( __("Single testimonials item", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
				"show_settings_on_create" => true,
				"class" => "trx_sc_collection trx_sc_column_item trx_sc_testimonials_item",
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_testimonials_item',
				"as_child" => array('only' => 'trx_testimonials'),
				"as_parent" => array('except' => 'trx_testimonials'),
				"params" => array(
					array(
						"param_name" => "author",
						"heading" => esc_html__("Author", "bierbaum"),
						"description" => wp_kses( __("Name of the testimonmials author", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link",
						"heading" => esc_html__("Link", "bierbaum"),
						"description" => wp_kses( __("Link URL to the testimonmials author page", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "email",
						"heading" => esc_html__("E-mail", "bierbaum"),
						"description" => wp_kses( __("E-mail of the testimonmials author", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "photo",
						"heading" => esc_html__("Photo", "bierbaum"),
						"description" => wp_kses( __("Select or upload photo of testimonmials author or write URL of photo from other site", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					/*
					array(
						"param_name" => "content",
						"heading" => esc_html__("Testimonials text", "bierbaum"),
						"description" => wp_kses( __("Current testimonials text", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textarea_html"
					),
					*/
					$BIERBAUM_GLOBALS['vc_params']['id'],
					$BIERBAUM_GLOBALS['vc_params']['class'],
					$BIERBAUM_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnItemView'
		) );
			
		class WPBakeryShortCode_Trx_Testimonials extends BIERBAUM_VC_ShortCodeColumns {}
		class WPBakeryShortCode_Trx_Testimonials_Item extends BIERBAUM_VC_ShortCodeCollection {}
		
	}
}
?>