<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_anchor_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_anchor_theme_setup' );
	function bierbaum_sc_anchor_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_anchor_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_anchor_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_anchor id="unique_id" description="Anchor description" title="Short Caption" icon="icon-class"]
*/

if (!function_exists('bierbaum_sc_anchor')) {	
	function bierbaum_sc_anchor($atts, $content = null) {
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"title" => "",
			"description" => '',
			"icon" => '',
			"url" => "",
			"separator" => "no",
			// Common params
			"id" => ""
		), $atts)));
		$output = $id 
			? '<a id="'.esc_attr($id).'"'
				. ' class="sc_anchor"' 
				. ' title="' . ($title ? esc_attr($title) : '') . '"'
				. ' data-description="' . ($description ? esc_attr(bierbaum_strmacros($description)) : ''). '"'
				. ' data-icon="' . ($icon ? $icon : '') . '"' 
				. ' data-url="' . ($url ? esc_attr($url) : '') . '"' 
				. ' data-separator="' . (bierbaum_param_is_on($separator) ? 'yes' : 'no') . '"'
				. '></a>'
			: '';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_anchor', $atts, $content);
	}
	bierbaum_require_shortcode("trx_anchor", "bierbaum_sc_anchor");
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_anchor_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_anchor_reg_shortcodes');
	function bierbaum_sc_anchor_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_anchor"] = array(
			"title" => esc_html__("Anchor", "bierbaum"),
			"desc" => wp_kses( __("Insert anchor for the TOC (table of content)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"icon" => array(
					"title" => esc_html__("Anchor's icon",  'bierbaum'),
					"desc" => wp_kses( __('Select icon for the anchor from Fontello icons set',  'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "icons",
					"options" => $BIERBAUM_GLOBALS['sc_params']['icons']
				),
				"title" => array(
					"title" => esc_html__("Short title", "bierbaum"),
					"desc" => wp_kses( __("Short title of the anchor (for the table of content)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"description" => array(
					"title" => esc_html__("Long description", "bierbaum"),
					"desc" => wp_kses( __("Description for the popup (then hover on the icon). You can use:<br>'{{' and '}}' - to make the text italic,<br>'((' and '))' - to make the text bold,<br>'||' - to insert line break", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"url" => array(
					"title" => esc_html__("External URL", "bierbaum"),
					"desc" => wp_kses( __("External URL for this TOC item", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"separator" => array(
					"title" => esc_html__("Add separator", "bierbaum"),
					"desc" => wp_kses( __("Add separator under item in the TOC", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "no",
					"type" => "switch",
					"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no']
				),
				"id" => $BIERBAUM_GLOBALS['sc_params']['id']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_anchor_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_anchor_reg_shortcodes_vc');
	function bierbaum_sc_anchor_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_anchor",
			"name" => esc_html__("Anchor", "bierbaum"),
			"description" => wp_kses( __("Insert anchor for the TOC (table of content)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_anchor',
			"class" => "trx_sc_single trx_sc_anchor",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "icon",
					"heading" => esc_html__("Anchor's icon", "bierbaum"),
					"description" => wp_kses( __("Select icon for the anchor from Fontello icons set", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => $BIERBAUM_GLOBALS['sc_params']['icons'],
					"type" => "dropdown"
				),
				array(
					"param_name" => "title",
					"heading" => esc_html__("Short title", "bierbaum"),
					"description" => wp_kses( __("Short title of the anchor (for the table of content)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "description",
					"heading" => esc_html__("Long description", "bierbaum"),
					"description" => wp_kses( __("Description for the popup (then hover on the icon). You can use:<br>'{{' and '}}' - to make the text italic,<br>'((' and '))' - to make the text bold,<br>'||' - to insert line break", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "url",
					"heading" => esc_html__("External URL", "bierbaum"),
					"description" => wp_kses( __("External URL for this TOC item", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "separator",
					"heading" => esc_html__("Add separator", "bierbaum"),
					"description" => wp_kses( __("Add separator under item in the TOC", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array("Add separator" => "yes" ),
					"type" => "checkbox"
				),
				$BIERBAUM_GLOBALS['vc_params']['id']
			),
		) );
		
		class WPBakeryShortCode_Trx_Anchor extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>