<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_audio_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_audio_theme_setup' );
	function bierbaum_sc_audio_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_audio_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_audio_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_audio url="http://trex2.themerex.dnw/wp-content/uploads/2014/12/Dream-Music-Relax.mp3" image="http://trex2.themerex.dnw/wp-content/uploads/2014/10/post_audio.jpg" title="Insert Audio Title Here" author="Lily Hunter" controls="show" autoplay="off"]
*/

if (!function_exists('bierbaum_sc_audio')) {	
	function bierbaum_sc_audio($atts, $content = null) {
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"title" => "",
			"author" => "",
			"image" => "",
			"mp3" => '',
			"wav" => '',
			"src" => '',
			"url" => '',
			"align" => '',
			"controls" => "",
			"autoplay" => "",
			"frame" => "on",
			// Common params
			"id" => "",
			"class" => "",
			"css" => "",
			"animation" => "",
			"width" => '',
			"height" => '',
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
		if ($src=='' && $url=='' && isset($atts[0])) {
			$src = $atts[0];
		}
		if ($src=='') {
			if ($url) $src = $url;
			else if ($mp3) $src = $mp3;
			else if ($wav) $src = $wav;
		}
		if ($image > 0) {
			$attach = wp_get_attachment_image_src( $image, 'full' );
			if (isset($attach[0]) && $attach[0]!='')
				$image = $attach[0];
		}
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		$data = ($title != ''  ? ' data-title="'.esc_attr($title).'"'   : '')
				. ($author != '' ? ' data-author="'.esc_attr($author).'"' : '')
				. ($image != ''  ? ' data-image="'.esc_url($image).'"'   : '')
				. ($align && $align!='none' ? ' data-align="'.esc_attr($align).'"' : '')
				. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '');
		$audio = '<audio'
			. ($id ? ' id="'.esc_attr($id).'"' : '')
			. ' class="sc_audio' . (!empty($class) ? ' '.esc_attr($class) : '') . '"'
			. ' src="'.esc_url($src).'"'
			. (bierbaum_param_is_on($controls) ? ' controls="controls"' : '')
			. (bierbaum_param_is_on($autoplay) && is_single() ? ' autoplay="autoplay"' : '')
			. ' width="'.esc_attr($width).'" height="'.esc_attr($height).'"'
			. ($css!='' ? ' style="'.esc_attr($css).'"' : '')
			. ($data)
			. '></audio>';
		if ( bierbaum_get_custom_option('substitute_audio')=='no') {
			if (bierbaum_param_is_on($frame)) {
				$audio = bierbaum_get_audio_frame($audio, $image, $s);
			}
		} else {
			if ((isset($_GET['vc_editable']) && $_GET['vc_editable']=='true') && (isset($_POST['action']) && $_POST['action']=='vc_load_shortcode')) {
				$audio = bierbaum_substitute_audio($audio, false);
			}
		}
		if (bierbaum_get_theme_option('use_mediaelement')=='yes')
			bierbaum_enqueue_script('wp-mediaelement');
		return apply_filters('bierbaum_shortcode_output', $audio, 'trx_audio', $atts, $content);
	}
	bierbaum_require_shortcode("trx_audio", "bierbaum_sc_audio");
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_audio_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_audio_reg_shortcodes');
	function bierbaum_sc_audio_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_audio"] = array(
			"title" => esc_html__("Audio", "bierbaum"),
			"desc" => wp_kses( __("Insert audio player", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"url" => array(
					"title" => esc_html__("URL for audio file", "bierbaum"),
					"desc" => wp_kses( __("URL for audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"readonly" => false,
					"value" => "",
					"type" => "media",
					"before" => array(
						'title' => esc_html__('Choose audio', 'bierbaum'),
						'action' => 'media_upload',
						'type' => 'audio',
						'multiple' => false,
						'linked_field' => '',
						'captions' => array( 	
							'choose' => esc_html__('Choose audio file', 'bierbaum'),
							'update' => esc_html__('Select audio file', 'bierbaum')
						)
					),
					"after" => array(
						'icon' => 'icon-cancel',
						'action' => 'media_reset'
					)
				),
				"image" => array(
					"title" => esc_html__("Cover image", "bierbaum"),
					"desc" => wp_kses( __("Select or upload image or write URL from other site for audio cover", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"readonly" => false,
					"value" => "",
					"type" => "media"
				),
				"title" => array(
					"title" => esc_html__("Title", "bierbaum"),
					"desc" => wp_kses( __("Title of the audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "",
					"type" => "text"
				),
				"author" => array(
					"title" => esc_html__("Author", "bierbaum"),
					"desc" => wp_kses( __("Author of the audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"controls" => array(
					"title" => esc_html__("Show controls", "bierbaum"),
					"desc" => wp_kses( __("Show controls in audio player", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"size" => "medium",
					"value" => "show",
					"type" => "switch",
					"options" => $BIERBAUM_GLOBALS['sc_params']['show_hide']
				),
				"autoplay" => array(
					"title" => esc_html__("Autoplay audio", "bierbaum"),
					"desc" => wp_kses( __("Autoplay audio on page load", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "off",
					"type" => "switch",
					"options" => $BIERBAUM_GLOBALS['sc_params']['on_off']
				),
				"align" => array(
					"title" => esc_html__("Align", "bierbaum"),
					"desc" => wp_kses( __("Select block alignment", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "none",
					"type" => "checklist",
					"dir" => "horizontal",
					"options" => $BIERBAUM_GLOBALS['sc_params']['align']
				),
				"width" => bierbaum_shortcodes_width(),
				"height" => bierbaum_shortcodes_height(),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_audio_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_audio_reg_shortcodes_vc');
	function bierbaum_sc_audio_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_audio",
			"name" => esc_html__("Audio", "bierbaum"),
			"description" => wp_kses( __("Insert audio player", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_audio',
			"class" => "trx_sc_single trx_sc_audio",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "url",
					"heading" => esc_html__("URL for audio file", "bierbaum"),
					"description" => wp_kses( __("Put here URL for audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "image",
					"heading" => esc_html__("Cover image", "bierbaum"),
					"description" => wp_kses( __("Select or upload image or write URL from other site for audio cover", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "attach_image"
				),
				array(
					"param_name" => "title",
					"heading" => esc_html__("Title", "bierbaum"),
					"description" => wp_kses( __("Title of the audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "author",
					"heading" => esc_html__("Author", "bierbaum"),
					"description" => wp_kses( __("Author of the audio file", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "controls",
					"heading" => esc_html__("Controls", "bierbaum"),
					"description" => wp_kses( __("Show/hide controls", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array("Hide controls" => "hide" ),
					"type" => "checkbox"
				),
				array(
					"param_name" => "autoplay",
					"heading" => esc_html__("Autoplay", "bierbaum"),
					"description" => wp_kses( __("Autoplay audio on page load", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array("Autoplay" => "on" ),
					"type" => "checkbox"
				),
				array(
					"param_name" => "align",
					"heading" => esc_html__("Alignment", "bierbaum"),
					"description" => wp_kses( __("Select block alignment", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['align']),
					"type" => "dropdown"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				bierbaum_vc_width(),
				bierbaum_vc_height(),
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			),
		) );
		
		class WPBakeryShortCode_Trx_Audio extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>