<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_quote_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_quote_theme_setup' );
	function bierbaum_sc_quote_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_quote_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_quote_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_quote id="unique_id" cite="url" title=""]Et adipiscing integer, scelerisque pid, augue mus vel tincidunt porta[/quote]
*/

if (!function_exists('bierbaum_sc_quote')) {	
	function bierbaum_sc_quote($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"title" => "",
			"cite" => "",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"width" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		$css .= bierbaum_get_css_dimensions_from_values($width);
		$cite_param = $cite != '' ? ' cite="'.esc_attr($cite).'"' : '';
		$title = $title=='' ? $cite : $title;
		$content = do_shortcode($content);
		if (bierbaum_substr($content, 0, 2)!='<p') $content = '<p>' . ($content) . '</p>';
		$output = '<blockquote' 
			. ($id ? ' id="'.esc_attr($id).'"' : '') . ($cite_param) 
			. ' class="sc_quote'. (!empty($class) ? ' '.esc_attr($class) : '').'"' 
			. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
			. ($css!='' ? ' style="'.esc_attr($css).'"' : '') 
			. '>'
				. ($content)
				. ($title == '' ? '' : ('<p class="sc_quote_title">' . ($cite!='' ? '<a href="'.esc_url($cite).'">' : '') . ($title) . ($cite!='' ? '</a>' : '') . '</p>'))
			.'</blockquote>';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_quote', $atts, $content);
	}
	bierbaum_require_shortcode('trx_quote', 'bierbaum_sc_quote');
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_quote_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_quote_reg_shortcodes');
	function bierbaum_sc_quote_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_quote"] = array(
			"title" => esc_html__("Quote", "bierbaum"),
			"desc" => wp_kses( __("Quote text", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => true,
			"params" => array(
				"cite" => array(
					"title" => esc_html__("Quote cite", "bierbaum"),
					"desc" => wp_kses( __("URL for quote cite", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"title" => array(
					"title" => esc_html__("Title (author)", "bierbaum"),
					"desc" => wp_kses( __("Quote title (author name)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"_content_" => array(
					"title" => esc_html__("Quote content", "bierbaum"),
					"desc" => wp_kses( __("Quote content", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"rows" => 4,
					"value" => "",
					"type" => "textarea"
				),
				"width" => bierbaum_shortcodes_width(),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_quote_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_quote_reg_shortcodes_vc');
	function bierbaum_sc_quote_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_quote",
			"name" => esc_html__("Quote", "bierbaum"),
			"description" => wp_kses( __("Quote text", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_quote',
			"class" => "trx_sc_single trx_sc_quote",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "cite",
					"heading" => esc_html__("Quote cite", "bierbaum"),
					"description" => wp_kses( __("URL for the quote cite link", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "title",
					"heading" => esc_html__("Title (author)", "bierbaum"),
					"description" => wp_kses( __("Quote title (author name)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "content",
					"heading" => esc_html__("Quote content", "bierbaum"),
					"description" => wp_kses( __("Quote content", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textarea_html"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				bierbaum_vc_width(),
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			),
			'js_view' => 'VcTrxTextView'
		) );
		
		class WPBakeryShortCode_Trx_Quote extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>