<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_socials_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_socials_theme_setup' );
	function bierbaum_sc_socials_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_socials_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_socials_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_socials id="unique_id" size="small"]
	[trx_social_item name="facebook" url="profile url" icon="path for the icon"]
	[trx_social_item name="twitter" url="profile url"]
[/trx_socials]
*/

if (!function_exists('bierbaum_sc_socials')) {	
	function bierbaum_sc_socials($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"size" => "small",		// tiny | small | medium | large
			"shape" => "square",	// round | square
			"type" => bierbaum_get_theme_setting('socials_type'),	// icons | images
			"socials" => "",
			"custom" => "no",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		global $BIERBAUM_GLOBALS;
		$BIERBAUM_GLOBALS['sc_social_icons'] = false;
		$BIERBAUM_GLOBALS['sc_social_type'] = $type;
		if (!empty($socials)) {
			$allowed = explode('|', $socials);
			$list = array();
			for ($i=0; $i<count($allowed); $i++) {
				$s = explode('=', $allowed[$i]);
				if (!empty($s[1])) {
					$list[] = array(
						'icon'	=> $type=='images' ? bierbaum_get_socials_url($s[0]) : 'icon-'.$s[0],
						'url'	=> $s[1]
						);
				}
			}
			if (count($list) > 0) $BIERBAUM_GLOBALS['sc_social_icons'] = $list;
		} else if (bierbaum_param_is_off($custom))
			$content = do_shortcode($content);
		if ($BIERBAUM_GLOBALS['sc_social_icons']===false) $BIERBAUM_GLOBALS['sc_social_icons'] = bierbaum_get_custom_option('social_icons');
		$output = bierbaum_prepare_socials($BIERBAUM_GLOBALS['sc_social_icons']);
		$output = $output
			? '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') 
				. ' class="sc_socials sc_socials_type_' . esc_attr($type) . ' sc_socials_shape_' . esc_attr($shape) . ' sc_socials_size_' . esc_attr($size) . (!empty($class) ? ' '.esc_attr($class) : '') . '"' 
				. ($css!='' ? ' style="'.esc_attr($css).'"' : '') 
				. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
				. '>' 
				. ($output)
				. '</div>'
			: '';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_socials', $atts, $content);
	}
	bierbaum_require_shortcode('trx_socials', 'bierbaum_sc_socials');
}


if (!function_exists('bierbaum_sc_social_item')) {	
	function bierbaum_sc_social_item($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"name" => "",
			"url" => "",
			"icon" => ""
		), $atts)));
		global $BIERBAUM_GLOBALS;
		if (!empty($name) && empty($icon)) {
			$type = $BIERBAUM_GLOBALS['sc_social_type'];
			if ($type=='images') {
				if (file_exists(bierbaum_get_socials_dir($name.'.png')))
					$icon = bierbaum_get_socials_url($name.'.png');
			} else
				$icon = 'icon-'.esc_attr($name);
		}
		if (!empty($icon) && !empty($url)) {
			if ($BIERBAUM_GLOBALS['sc_social_icons']===false) $BIERBAUM_GLOBALS['sc_social_icons'] = array();
			$BIERBAUM_GLOBALS['sc_social_icons'][] = array(
				'icon' => $icon,
				'url' => $url
			);
		}
		return '';
	}
	bierbaum_require_shortcode('trx_social_item', 'bierbaum_sc_social_item');
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_socials_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_socials_reg_shortcodes');
	function bierbaum_sc_socials_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_socials"] = array(
			"title" => esc_html__("Social icons", "bierbaum"),
			"desc" => wp_kses( __("List of social icons (with hovers)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => true,
			"container" => false,
			"params" => array(
				"type" => array(
					"title" => esc_html__("Icon's type", "bierbaum"),
					"desc" => wp_kses( __("Type of the icons - images or font icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => bierbaum_get_theme_setting('socials_type'),
					"options" => array(
						'icons' => esc_html__('Icons', 'bierbaum'),
						'images' => esc_html__('Images', 'bierbaum')
					),
					"type" => "checklist"
				), 
				"size" => array(
					"title" => esc_html__("Icon's size", "bierbaum"),
					"desc" => wp_kses( __("Size of the icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "small",
					"options" => $BIERBAUM_GLOBALS['sc_params']['sizes'],
					"type" => "checklist"
				), 
				"shape" => array(
					"title" => esc_html__("Icon's shape", "bierbaum"),
					"desc" => wp_kses( __("Shape of the icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "square",
					"options" => $BIERBAUM_GLOBALS['sc_params']['shapes'],
					"type" => "checklist"
				), 
				"socials" => array(
					"title" => esc_html__("Manual socials list", "bierbaum"),
					"desc" => wp_kses( __("Custom list of social networks. For example: twitter=http://twitter.com/my_profile|facebook=http://facebook.com/my_profile. If empty - use socials from Theme options.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "",
					"type" => "text"
				),
				"custom" => array(
					"title" => esc_html__("Custom socials", "bierbaum"),
					"desc" => wp_kses( __("Make custom icons from inner shortcodes (prepare it on tabs)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "no",
					"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no'],
					"type" => "switch"
				),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			),
			"children" => array(
				"name" => "trx_social_item",
				"title" => esc_html__("Custom social item", "bierbaum"),
				"desc" => wp_kses( __("Custom social item: name, profile url and icon url", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
				"decorate" => false,
				"container" => false,
				"params" => array(
					"name" => array(
						"title" => esc_html__("Social name", "bierbaum"),
						"desc" => wp_kses( __("Name (slug) of the social network (twitter, facebook, linkedin, etc.)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"value" => "",
						"type" => "text"
					),
					"url" => array(
						"title" => esc_html__("Your profile URL", "bierbaum"),
						"desc" => wp_kses( __("URL of your profile in specified social network", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"value" => "",
						"type" => "text"
					),
					"icon" => array(
						"title" => esc_html__("URL (source) for icon file", "bierbaum"),
						"desc" => wp_kses( __("Select or upload image or write URL from other site for the current social icon", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
						"readonly" => false,
						"value" => "",
						"type" => "media"
					)
				)
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_socials_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_socials_reg_shortcodes_vc');
	function bierbaum_sc_socials_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_socials",
			"name" => esc_html__("Social icons", "bierbaum"),
			"description" => wp_kses( __("Custom social icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_socials',
			"class" => "trx_sc_collection trx_sc_socials",
			"content_element" => true,
			"is_container" => true,
			"show_settings_on_create" => true,
			"as_parent" => array('only' => 'trx_social_item'),
			"params" => array_merge(array(
				array(
					"param_name" => "type",
					"heading" => esc_html__("Icon's type", "bierbaum"),
					"description" => wp_kses( __("Type of the icons - images or font icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"std" => bierbaum_get_theme_setting('socials_type'),
					"value" => array(
						esc_html__('Icons', 'bierbaum') => 'icons',
						esc_html__('Images', 'bierbaum') => 'images'
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "size",
					"heading" => esc_html__("Icon's size", "bierbaum"),
					"description" => wp_kses( __("Size of the icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"std" => "small",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['sizes']),
					"type" => "dropdown"
				),
				array(
					"param_name" => "shape",
					"heading" => esc_html__("Icon's shape", "bierbaum"),
					"description" => wp_kses( __("Shape of the icons", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"std" => "square",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['shapes']),
					"type" => "dropdown"
				),
				array(
					"param_name" => "socials",
					"heading" => esc_html__("Manual socials list", "bierbaum"),
					"description" => wp_kses( __("Custom list of social networks. For example: twitter=http://twitter.com/my_profile|facebook=http://facebook.com/my_profile. If empty - use socials from Theme options.", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "custom",
					"heading" => esc_html__("Custom socials", "bierbaum"),
					"description" => wp_kses( __("Make custom icons from inner shortcodes (prepare it on tabs)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(esc_html__('Custom socials', 'bierbaum') => 'yes'),
					"type" => "checkbox"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			))
		) );
		
		
		vc_map( array(
			"base" => "trx_social_item",
			"name" => esc_html__("Custom social item", "bierbaum"),
			"description" => wp_kses( __("Custom social item: name, profile url and icon url", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"show_settings_on_create" => true,
			"content_element" => true,
			"is_container" => false,
			'icon' => 'icon_trx_social_item',
			"class" => "trx_sc_single trx_sc_social_item",
			"as_child" => array('only' => 'trx_socials'),
			"as_parent" => array('except' => 'trx_socials'),
			"params" => array(
				array(
					"param_name" => "name",
					"heading" => esc_html__("Social name", "bierbaum"),
					"description" => wp_kses( __("Name (slug) of the social network (twitter, facebook, linkedin, etc.)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "url",
					"heading" => esc_html__("Your profile URL", "bierbaum"),
					"description" => wp_kses( __("URL of your profile in specified social network", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "icon",
					"heading" => esc_html__("URL (source) for icon file", "bierbaum"),
					"description" => wp_kses( __("Select or upload image or write URL from other site for the current social icon", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "attach_image"
				)
			)
		) );
		
		class WPBakeryShortCode_Trx_Socials extends BIERBAUM_VC_ShortCodeCollection {}
		class WPBakeryShortCode_Trx_Social_Item extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>