<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_table_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_table_theme_setup' );
	function bierbaum_sc_table_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_table_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_table_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_table id="unique_id" style="1"]
Table content, generated on one of many public internet resources, for example: http://www.impressivewebs.com/html-table-code-generator/
[/trx_table]
*/

if (!function_exists('bierbaum_sc_table')) {	
	function bierbaum_sc_table($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"align" => "",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => "",
			"width" => "100%"
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		$css .= bierbaum_get_css_dimensions_from_values($width);
		$content = str_replace(
					array('<p><table', 'table></p>', '><br />'),
					array('<table', 'table>', '>'),
					html_entity_decode($content, ENT_COMPAT, 'UTF-8'));
		$output = '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') 
				. ' class="sc_table' 
					. (!empty($align) && $align!='none' ? ' align'.esc_attr($align) : '') 
					. (!empty($class) ? ' '.esc_attr($class) : '') 
					. '"'
				. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
				. ($css!='' ? ' style="'.esc_attr($css).'"' : '') 
				.'>' 
				. do_shortcode($content) 
				. '</div>';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_table', $atts, $content);
	}
	bierbaum_require_shortcode('trx_table', 'bierbaum_sc_table');
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_table_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_table_reg_shortcodes');
	function bierbaum_sc_table_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_table"] = array(
			"title" => esc_html__("Table", "bierbaum"),
			"desc" => wp_kses( __("Insert a table into post (page). ", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => true,
			"container" => true,
			"params" => array(
				"align" => array(
					"title" => esc_html__("Content alignment", "bierbaum"),
					"desc" => wp_kses( __("Select alignment for each table cell", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "none",
					"type" => "checklist",
					"dir" => "horizontal",
					"options" => $BIERBAUM_GLOBALS['sc_params']['align']
				),
				"_content_" => array(
					"title" => esc_html__("Table content", "bierbaum"),
					"desc" => wp_kses( __("Content, created with any table-generator", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"rows" => 8,
					"value" => "Paste here table content, generated on one of many public internet resources, for example: http://www.impressivewebs.com/html-table-code-generator/ or http://html-tables.com/",
					"type" => "textarea"
				),
				"width" => bierbaum_shortcodes_width(),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_table_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_table_reg_shortcodes_vc');
	function bierbaum_sc_table_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_table",
			"name" => esc_html__("Table", "bierbaum"),
			"description" => wp_kses( __("Insert a table", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_table',
			"class" => "trx_sc_container trx_sc_table",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "align",
					"heading" => esc_html__("Cells content alignment", "bierbaum"),
					"description" => wp_kses( __("Select alignment for each table cell", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['align']),
					"type" => "dropdown"
				),
				array(
					"param_name" => "content",
					"heading" => esc_html__("Table content", "bierbaum"),
					"description" => wp_kses( __("Content, created with any table-generator", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => esc_html__("Paste here table content, generated on one of many public internet resources, for example: http://www.impressivewebs.com/html-table-code-generator/ or http://html-tables.com/", 'bierbaum'),
					"type" => "textarea_html"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				bierbaum_vc_width(),
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			),
			'js_view' => 'VcTrxTextContainerView'
		) );
		
		class WPBakeryShortCode_Trx_Table extends BIERBAUM_VC_ShortCodeContainer {}
	}
}
?>