<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_title_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_title_theme_setup' );
	function bierbaum_sc_title_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_title_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_title_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_title id="unique_id" style='regular|iconed' icon='' image='' background="on|off" type="1-6"]Et adipiscing integer, scelerisque pid, augue mus vel tincidunt porta[/trx_title]
*/

if (!function_exists('bierbaum_sc_title')) {	
	function bierbaum_sc_title($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"type" => "1",
			"style" => "regular",
			"align" => "",
			"font_weight" => "",
			"font_size" => "",
			"color" => "",
			"icon" => "",
			"image" => "",
			"picture" => "",
			"image_size" => "small",
			"position" => "left",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"width" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		$css .= bierbaum_get_css_dimensions_from_values($width)
			.($align && $align!='none' && !bierbaum_param_is_inherit($align) ? 'text-align:' . esc_attr($align) .';' : '')
			.($color ? 'color:' . esc_attr($color) .';' : '')
			.($font_weight && !bierbaum_param_is_inherit($font_weight) ? 'font-weight:' . esc_attr($font_weight) .';' : '')
			.($font_size   ? 'font-size:' . esc_attr($font_size) .';' : '')
			;
		$type = min(6, max(1, $type));
		if ($picture > 0) {
			$attach = wp_get_attachment_image_src( $picture, 'full' );
			if (isset($attach[0]) && $attach[0]!='')
				$picture = $attach[0];
		}
		$pic = $style!='iconed' 
			? '' 
			: '<span class="sc_title_icon sc_title_icon_'.esc_attr($position).'  sc_title_icon_'.esc_attr($image_size).($icon!='' && $icon!='none' ? ' '.esc_attr($icon) : '').'"'.'>'
				.($picture ? '<img src="'.esc_url($picture).'" alt="" />' : '')
				.(empty($picture) && $image && $image!='none' ? '<img src="'.esc_url(bierbaum_strpos($image, 'http:')!==false ? $image : bierbaum_get_file_url('images/icons/'.($image).'.png')).'" alt="" />' : '')
				.'</span>';
		$output = '<h' . esc_attr($type) . ($id ? ' id="'.esc_attr($id).'"' : '')
				. ' class="sc_title sc_title_'.esc_attr($style)
					.($align && $align!='none' && !bierbaum_param_is_inherit($align) ? ' sc_align_' . esc_attr($align) : '')
					.(!empty($class) ? ' '.esc_attr($class) : '')
					.'"'
				. ($css!='' ? ' style="'.esc_attr($css).'"' : '')
				. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
				. '>'
					. ($pic)
					. ($style=='divider' ? '<span class="sc_title_divider_before"'.($color ? ' style="background-color: '.esc_attr($color).'"' : '').'></span>' : '')
					. do_shortcode($content) 
					. ($style=='divider' ? '<span class="sc_title_divider_after"'.($color ? ' style="background-color: '.esc_attr($color).'"' : '').'></span>' : '')
				. '</h' . esc_attr($type) . '>';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_title', $atts, $content);
	}
	bierbaum_require_shortcode('trx_title', 'bierbaum_sc_title');
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_title_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_title_reg_shortcodes');
	function bierbaum_sc_title_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_title"] = array(
			"title" => esc_html__("Title", "bierbaum"),
			"desc" => wp_kses( __("Create header tag (1-6 level) with many styles", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => true,
			"params" => array(
				"_content_" => array(
					"title" => esc_html__("Title content", "bierbaum"),
					"desc" => wp_kses( __("Title content", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"rows" => 4,
					"value" => "",
					"type" => "textarea"
				),
				"type" => array(
					"title" => esc_html__("Title type", "bierbaum"),
					"desc" => wp_kses( __("Title type (header level)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "1",
					"type" => "select",
					"options" => array(
						'1' => esc_html__('Header 1', 'bierbaum'),
						'2' => esc_html__('Header 2', 'bierbaum'),
						'3' => esc_html__('Header 3', 'bierbaum'),
						'4' => esc_html__('Header 4', 'bierbaum'),
						'5' => esc_html__('Header 5', 'bierbaum'),
						'6' => esc_html__('Header 6', 'bierbaum'),
					)
				),
				"style" => array(
					"title" => esc_html__("Title style", "bierbaum"),
					"desc" => wp_kses( __("Title style", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "regular",
					"type" => "select",
					"options" => array(
						'regular' => esc_html__('Regular', 'bierbaum'),
						'underline' => esc_html__('Underline', 'bierbaum'),
						'divider' => esc_html__('Divider', 'bierbaum'),
						'iconed' => esc_html__('With icon (image)', 'bierbaum')
					)
				),
				"align" => array(
					"title" => esc_html__("Alignment", "bierbaum"),
					"desc" => wp_kses( __("Title text alignment", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "checklist",
					"dir" => "horizontal",
					"options" => $BIERBAUM_GLOBALS['sc_params']['align']
				), 
				"font_size" => array(
					"title" => esc_html__("Font_size", "bierbaum"),
					"desc" => wp_kses( __("Custom font size. If empty - use theme default", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"font_weight" => array(
					"title" => esc_html__("Font weight", "bierbaum"),
					"desc" => wp_kses( __("Custom font weight. If empty or inherit - use theme default", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "select",
					"size" => "medium",
					"options" => array(
						'inherit' => esc_html__('Default', 'bierbaum'),
						'100' => esc_html__('Thin (100)', 'bierbaum'),
						'300' => esc_html__('Light (300)', 'bierbaum'),
						'400' => esc_html__('Normal (400)', 'bierbaum'),
						'600' => esc_html__('Semibold (600)', 'bierbaum'),
						'700' => esc_html__('Bold (700)', 'bierbaum'),
						'900' => esc_html__('Black (900)', 'bierbaum')
					)
				),
				"color" => array(
					"title" => esc_html__("Title color", "bierbaum"),
					"desc" => wp_kses( __("Select color for the title", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "color"
				),
				"icon" => array(
					"title" => esc_html__('Title font icon',  'bierbaum'),
					"desc" => wp_kses( __("Select font icon for the title from Fontello icons set (if style=iconed)",  'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"dependency" => array(
						'style' => array('iconed')
					),
					"value" => "",
					"type" => "icons",
					"options" => $BIERBAUM_GLOBALS['sc_params']['icons']
				),
				"image" => array(
					"title" => esc_html__('or image icon',  'bierbaum'),
					"desc" => wp_kses( __("Select image icon for the title instead icon above (if style=iconed)",  'bierbaum'), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"dependency" => array(
						'style' => array('iconed')
					),
					"value" => "",
					"type" => "images",
					"size" => "small",
					"options" => $BIERBAUM_GLOBALS['sc_params']['images']
				),
				"picture" => array(
					"title" => esc_html__('or URL for image file', "bierbaum"),
					"desc" => wp_kses( __("Select or upload image or write URL from other site (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"dependency" => array(
						'style' => array('iconed')
					),
					"readonly" => false,
					"value" => "",
					"type" => "media"
				),
				"image_size" => array(
					"title" => esc_html__('Image (picture) size', "bierbaum"),
					"desc" => wp_kses( __("Select image (picture) size (if style='iconed')", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"dependency" => array(
						'style' => array('iconed')
					),
					"value" => "small",
					"type" => "checklist",
					"options" => array(
						'small' => esc_html__('Small', 'bierbaum'),
						'medium' => esc_html__('Medium', 'bierbaum'),
						'large' => esc_html__('Large', 'bierbaum')
					)
				),
				"position" => array(
					"title" => esc_html__('Icon (image) position', "bierbaum"),
					"desc" => wp_kses( __("Select icon (image) position (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"dependency" => array(
						'style' => array('iconed')
					),
					"value" => "left",
					"type" => "checklist",
					"options" => array(
						'top' => esc_html__('Top', 'bierbaum'),
						'left' => esc_html__('Left', 'bierbaum')
					)
				),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_title_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_title_reg_shortcodes_vc');
	function bierbaum_sc_title_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_title",
			"name" => esc_html__("Title", "bierbaum"),
			"description" => wp_kses( __("Create header tag (1-6 level) with many styles", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_title',
			"class" => "trx_sc_single trx_sc_title",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "content",
					"heading" => esc_html__("Title content", "bierbaum"),
					"description" => wp_kses( __("Title content", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textarea_html"
				),
				array(
					"param_name" => "type",
					"heading" => esc_html__("Title type", "bierbaum"),
					"description" => wp_kses( __("Title type (header level)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => array(
						esc_html__('Header 1', 'bierbaum') => '1',
						esc_html__('Header 2', 'bierbaum') => '2',
						esc_html__('Header 3', 'bierbaum') => '3',
						esc_html__('Header 4', 'bierbaum') => '4',
						esc_html__('Header 5', 'bierbaum') => '5',
						esc_html__('Header 6', 'bierbaum') => '6'
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "style",
					"heading" => esc_html__("Title style", "bierbaum"),
					"description" => wp_kses( __("Title style: only text (regular) or with icon/image (iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => array(
						esc_html__('Regular', 'bierbaum') => 'regular',
						esc_html__('Underline', 'bierbaum') => 'underline',
						esc_html__('Divider', 'bierbaum') => 'divider',
						esc_html__('With icon (image)', 'bierbaum') => 'iconed'
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "align",
					"heading" => esc_html__("Alignment", "bierbaum"),
					"description" => wp_kses( __("Title text alignment", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['align']),
					"type" => "dropdown"
				),
				array(
					"param_name" => "font_size",
					"heading" => esc_html__("Font size", "bierbaum"),
					"description" => wp_kses( __("Custom font size. If empty - use theme default", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "font_weight",
					"heading" => esc_html__("Font weight", "bierbaum"),
					"description" => wp_kses( __("Custom font weight. If empty or inherit - use theme default", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(
						esc_html__('Default', 'bierbaum') => 'inherit',
						esc_html__('Thin (100)', 'bierbaum') => '100',
						esc_html__('Light (300)', 'bierbaum') => '300',
						esc_html__('Normal (400)', 'bierbaum') => '400',
						esc_html__('Semibold (600)', 'bierbaum') => '600',
						esc_html__('Bold (700)', 'bierbaum') => '700',
						esc_html__('Black (900)', 'bierbaum') => '900'
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "color",
					"heading" => esc_html__("Title color", "bierbaum"),
					"description" => wp_kses( __("Select color for the title", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => "",
					"type" => "colorpicker"
				),
				array(
					"param_name" => "icon",
					"heading" => esc_html__("Title font icon", "bierbaum"),
					"description" => wp_kses( __("Select font icon for the title from Fontello icons set (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"group" => esc_html__('Icon &amp; Image', 'bierbaum'),
					'dependency' => array(
						'element' => 'style',
						'value' => array('iconed')
					),
					"value" => $BIERBAUM_GLOBALS['sc_params']['icons'],
					"type" => "dropdown"
				),
				array(
					"param_name" => "image",
					"heading" => esc_html__("or image icon", "bierbaum"),
					"description" => wp_kses( __("Select image icon for the title instead icon above (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"group" => esc_html__('Icon &amp; Image', 'bierbaum'),
					'dependency' => array(
						'element' => 'style',
						'value' => array('iconed')
					),
					"value" => $BIERBAUM_GLOBALS['sc_params']['images'],
					"type" => "dropdown"
				),
				array(
					"param_name" => "picture",
					"heading" => esc_html__("or select uploaded image", "bierbaum"),
					"description" => wp_kses( __("Select or upload image or write URL from other site (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"group" => esc_html__('Icon &amp; Image', 'bierbaum'),
					"class" => "",
					"value" => "",
					"type" => "attach_image"
				),
				array(
					"param_name" => "image_size",
					"heading" => esc_html__("Image (picture) size", "bierbaum"),
					"description" => wp_kses( __("Select image (picture) size (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"group" => esc_html__('Icon &amp; Image', 'bierbaum'),
					"class" => "",
					"value" => array(
						esc_html__('Small', 'bierbaum') => 'small',
						esc_html__('Medium', 'bierbaum') => 'medium',
						esc_html__('Large', 'bierbaum') => 'large'
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "position",
					"heading" => esc_html__("Icon (image) position", "bierbaum"),
					"description" => wp_kses( __("Select icon (image) position (if style=iconed)", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"group" => esc_html__('Icon &amp; Image', 'bierbaum'),
					"class" => "",
					"std" => "left",
					"value" => array(
						esc_html__('Top', 'bierbaum') => 'top',
						esc_html__('Left', 'bierbaum') => 'left'
					),
					"type" => "dropdown"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			),
			'js_view' => 'VcTrxTextView'
		) );
		
		class WPBakeryShortCode_Trx_Title extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>