<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_emailer_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_emailer_theme_setup' );
	function bierbaum_sc_emailer_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_emailer_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_emailer_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

//[trx_emailer group=""]

if (!function_exists('bierbaum_sc_emailer')) {	
	function bierbaum_sc_emailer($atts, $content = null) {
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"group" => "",
			"open" => "yes",
			"align" => "",
			// Common params
			"id" => "",
			"class" => "",
			"css" => "",
			"animation" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => "",
			"width" => "",
			"height" => ""
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		$css .= bierbaum_get_css_dimensions_from_values($width, $height);
		// Load core messages
		bierbaum_enqueue_messages();
		$output = '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
					. ' class="sc_emailer' . ($align && $align!='none' ? ' align' . esc_attr($align) : '') . (bierbaum_param_is_on($open) ? ' sc_emailer_opened' : '') . (!empty($class) ? ' '.esc_attr($class) : '') . '"' 
					. ($css ? ' style="'.esc_attr($css).'"' : '') 
					. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
					. '>'
				. '<form class="sc_emailer_form">'
				. '<input type="text" class="sc_emailer_input" name="email" value="" placeholder="'.esc_attr__('Please, enter you email address.', 'bierbaum').'">'
				. '<a href="#" class="sc_emailer_button icon-mail" title="'.esc_attr__('Submit', 'bierbaum').'" data-group="'.esc_attr($group ? $group : esc_html__('E-mailer subscription', 'bierbaum')).'"></a>'
				. '</form>'
			. '</div>';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_emailer', $atts, $content);
	}
	bierbaum_require_shortcode("trx_emailer", "bierbaum_sc_emailer");
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_emailer_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_emailer_reg_shortcodes');
	function bierbaum_sc_emailer_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_emailer"] = array(
			"title" => esc_html__("E-mail collector", "bierbaum"),
			"desc" => wp_kses( __("Collect the e-mail address into specified group", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"group" => array(
					"title" => esc_html__("Group", "bierbaum"),
					"desc" => wp_kses( __("The name of group to collect e-mail address", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"open" => array(
					"title" => esc_html__("Open", "bierbaum"),
					"desc" => wp_kses( __("Initially open the input field on show object", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "yes",
					"type" => "switch",
					"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no']
				),
				"align" => array(
					"title" => esc_html__("Alignment", "bierbaum"),
					"desc" => wp_kses( __("Align object to left, center or right", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"divider" => true,
					"value" => "none",
					"type" => "checklist",
					"dir" => "horizontal",
					"options" => $BIERBAUM_GLOBALS['sc_params']['align']
				), 
				"width" => bierbaum_shortcodes_width(),
				"height" => bierbaum_shortcodes_height(),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_emailer_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_emailer_reg_shortcodes_vc');
	function bierbaum_sc_emailer_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_emailer",
			"name" => esc_html__("E-mail collector", "bierbaum"),
			"description" => wp_kses( __("Collect e-mails into specified group", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_emailer',
			"class" => "trx_sc_single trx_sc_emailer",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "group",
					"heading" => esc_html__("Group", "bierbaum"),
					"description" => wp_kses( __("The name of group to collect e-mail address", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => "",
					"type" => "textfield"
				),
				array(
					"param_name" => "open",
					"heading" => esc_html__("Opened", "bierbaum"),
					"description" => wp_kses( __("Initially open the input field on show object", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(esc_html__('Initially opened', 'bierbaum') => 'yes'),
					"type" => "checkbox"
				),
				array(
					"param_name" => "align",
					"heading" => esc_html__("Alignment", "bierbaum"),
					"description" => wp_kses( __("Align field to left, center or right", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => array_flip($BIERBAUM_GLOBALS['sc_params']['align']),
					"type" => "dropdown"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				bierbaum_vc_width(),
				bierbaum_vc_height(),
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			)
		) );
		
		class WPBakeryShortCode_Trx_Emailer extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>