<?php

/* Theme setup section
-------------------------------------------------------------------- */
if (!function_exists('bierbaum_sc_search_theme_setup')) {
	add_action( 'bierbaum_action_before_init_theme', 'bierbaum_sc_search_theme_setup' );
	function bierbaum_sc_search_theme_setup() {
		add_action('bierbaum_action_shortcodes_list', 		'bierbaum_sc_search_reg_shortcodes');
		if (function_exists('bierbaum_exists_visual_composer') && bierbaum_exists_visual_composer())
			add_action('bierbaum_action_shortcodes_list_vc','bierbaum_sc_search_reg_shortcodes_vc');
	}
}



/* Shortcode implementation
-------------------------------------------------------------------- */

/*
[trx_search id="unique_id" open="yes|no"]
*/

if (!function_exists('bierbaum_sc_search')) {	
	function bierbaum_sc_search($atts, $content=null){	
		if (bierbaum_in_shortcode_blogger()) return '';
		extract(bierbaum_html_decode(shortcode_atts(array(
			// Individual params
			"style" => "regular",
			"state" => "fixed",
			"scheme" => "original",
			"ajax" => "",
			"title" => esc_html__('Search', 'bierbaum'),
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
		$class .= ($class ? ' ' : '') . bierbaum_get_css_position_as_classes($top, $right, $bottom, $left);
		if (empty($ajax)) $ajax = bierbaum_get_theme_option('use_ajax_search');
		// Load core messages
		bierbaum_enqueue_messages();
		$output = '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') . ' class="search_wrap search_style_'.esc_attr($style).' search_state_'.esc_attr($state)
						. (bierbaum_param_is_on($ajax) ? ' search_ajax' : '')
						. ($class ? ' '.esc_attr($class) : '')
						. '"'
					. ($css!='' ? ' style="'.esc_attr($css).'"' : '')
					. (!bierbaum_param_is_off($animation) ? ' data-animation="'.esc_attr(bierbaum_get_animation_classes($animation)).'"' : '')
					. '>
						<div class="search_form_wrap">
							<form role="search" method="get" class="search_form" action="' . esc_url(home_url('/')) . '">
								<button type="submit" class="search_submit icon-search" title="' . ($state=='closed' ? esc_attr__('Open search', 'bierbaum') : esc_attr__('Start search', 'bierbaum')) . '"></button>
								<input type="text" class="search_field" placeholder="' . esc_attr($title) . '" value="' . esc_attr(get_search_query()) . '" name="s" />
							</form>
						</div>
						<div class="search_results widget_area' . ($scheme && !bierbaum_param_is_off($scheme) && !bierbaum_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '') . '"><a class="search_results_close icon-cancel"></a><div class="search_results_content"></div></div>
				</div>';
		return apply_filters('bierbaum_shortcode_output', $output, 'trx_search', $atts, $content);
	}
	bierbaum_require_shortcode('trx_search', 'bierbaum_sc_search');
}



/* Add shortcode in the internal SC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_search_reg_shortcodes' ) ) {
	//add_action('bierbaum_action_shortcodes_list', 'bierbaum_sc_search_reg_shortcodes');
	function bierbaum_sc_search_reg_shortcodes() {
		global $BIERBAUM_GLOBALS;
	
		$BIERBAUM_GLOBALS['shortcodes']["trx_search"] = array(
			"title" => esc_html__("Search", "bierbaum"),
			"desc" => wp_kses( __("Show search form", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"style" => array(
					"title" => esc_html__("Style", "bierbaum"),
					"desc" => wp_kses( __("Select style to display search field", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "regular",
					"options" => array(
						"regular" => esc_html__('Regular', 'bierbaum'),
						"rounded" => esc_html__('Rounded', 'bierbaum')
					),
					"type" => "checklist"
				),
				"state" => array(
					"title" => esc_html__("State", "bierbaum"),
					"desc" => wp_kses( __("Select search field initial state", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "fixed",
					"options" => array(
						"fixed"  => esc_html__('Fixed',  'bierbaum'),
						"opened" => esc_html__('Opened', 'bierbaum'),
						"closed" => esc_html__('Closed', 'bierbaum')
					),
					"type" => "checklist"
				),
				"title" => array(
					"title" => esc_html__("Title", "bierbaum"),
					"desc" => wp_kses( __("Title (placeholder) for the search field", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => esc_html__("Search &hellip;", 'bierbaum'),
					"type" => "text"
				),
				"ajax" => array(
					"title" => esc_html__("AJAX", "bierbaum"),
					"desc" => wp_kses( __("Search via AJAX or reload page", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"value" => "yes",
					"options" => $BIERBAUM_GLOBALS['sc_params']['yes_no'],
					"type" => "switch"
				),
				"top" => $BIERBAUM_GLOBALS['sc_params']['top'],
				"bottom" => $BIERBAUM_GLOBALS['sc_params']['bottom'],
				"left" => $BIERBAUM_GLOBALS['sc_params']['left'],
				"right" => $BIERBAUM_GLOBALS['sc_params']['right'],
				"id" => $BIERBAUM_GLOBALS['sc_params']['id'],
				"class" => $BIERBAUM_GLOBALS['sc_params']['class'],
				"animation" => $BIERBAUM_GLOBALS['sc_params']['animation'],
				"css" => $BIERBAUM_GLOBALS['sc_params']['css']
			)
		);
	}
}


/* Add shortcode in the VC Builder
-------------------------------------------------------------------- */
if ( !function_exists( 'bierbaum_sc_search_reg_shortcodes_vc' ) ) {
	//add_action('bierbaum_action_shortcodes_list_vc', 'bierbaum_sc_search_reg_shortcodes_vc');
	function bierbaum_sc_search_reg_shortcodes_vc() {
		global $BIERBAUM_GLOBALS;
	
		vc_map( array(
			"base" => "trx_search",
			"name" => esc_html__("Search form", "bierbaum"),
			"description" => wp_kses( __("Insert search form", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
			"category" => esc_html__('Content', 'bierbaum'),
			'icon' => 'icon_trx_search',
			"class" => "trx_sc_single trx_sc_search",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "style",
					"heading" => esc_html__("Style", "bierbaum"),
					"description" => wp_kses( __("Select style to display search field", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(
						esc_html__('Regular', 'bierbaum') => "regular",
						esc_html__('Flat', 'bierbaum') => "flat"
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "state",
					"heading" => esc_html__("State", "bierbaum"),
					"description" => wp_kses( __("Select search field initial state", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(
						esc_html__('Fixed', 'bierbaum')  => "fixed",
						esc_html__('Opened', 'bierbaum') => "opened",
						esc_html__('Closed', 'bierbaum') => "closed"
					),
					"type" => "dropdown"
				),
				array(
					"param_name" => "title",
					"heading" => esc_html__("Title", "bierbaum"),
					"description" => wp_kses( __("Title (placeholder) for the search field", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"admin_label" => true,
					"class" => "",
					"value" => esc_html__("Search &hellip;", 'bierbaum'),
					"type" => "textfield"
				),
				array(
					"param_name" => "ajax",
					"heading" => esc_html__("AJAX", "bierbaum"),
					"description" => wp_kses( __("Search via AJAX or reload page", "bierbaum"), $BIERBAUM_GLOBALS['allowed_tags'] ),
					"class" => "",
					"value" => array(esc_html__('Use AJAX search', 'bierbaum') => 'yes'),
					"type" => "checkbox"
				),
				$BIERBAUM_GLOBALS['vc_params']['id'],
				$BIERBAUM_GLOBALS['vc_params']['class'],
				$BIERBAUM_GLOBALS['vc_params']['animation'],
				$BIERBAUM_GLOBALS['vc_params']['css'],
				$BIERBAUM_GLOBALS['vc_params']['margin_top'],
				$BIERBAUM_GLOBALS['vc_params']['margin_bottom'],
				$BIERBAUM_GLOBALS['vc_params']['margin_left'],
				$BIERBAUM_GLOBALS['vc_params']['margin_right']
			)
		) );
		
		class WPBakeryShortCode_Trx_Search extends BIERBAUM_VC_ShortCodeSingle {}
	}
}
?>