<?php
/**
 * Skin file for the theme.
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('bierbaum_action_skin_theme_setup')) {
	add_action( 'bierbaum_action_init_theme', 'bierbaum_action_skin_theme_setup', 1 );
	function bierbaum_action_skin_theme_setup() {

		// Add skin fonts in the used fonts list
		add_filter('bierbaum_filter_used_fonts',			'bierbaum_filter_skin_used_fonts');
		// Add skin fonts (from Google fonts) in the main fonts list (if not present).
		add_filter('bierbaum_filter_list_fonts',			'bierbaum_filter_skin_list_fonts');

		// Add skin stylesheets
		add_action('bierbaum_action_add_styles',			'bierbaum_action_skin_add_styles');
		// Add skin inline styles
		add_filter('bierbaum_filter_add_styles_inline',		'bierbaum_filter_skin_add_styles_inline');
		// Add skin responsive styles
		add_action('bierbaum_action_add_responsive',		'bierbaum_action_skin_add_responsive');
		// Add skin responsive inline styles
		add_filter('bierbaum_filter_add_responsive_inline',	'bierbaum_filter_skin_add_responsive_inline');

		// Add skin scripts
		add_action('bierbaum_action_add_scripts',			'bierbaum_action_skin_add_scripts');
		// Add skin scripts inline
		add_action('bierbaum_action_add_scripts_inline',	'bierbaum_action_skin_add_scripts_inline');

		// Add skin less files into list for compilation
		add_filter('bierbaum_filter_compile_less',			'bierbaum_filter_skin_compile_less');


		/* Color schemes
		
		// Accenterd colors
		accent1			- theme accented color 1
		accent1_hover	- theme accented color 1 (hover state)
		accent2			- theme accented color 2
		accent2_hover	- theme accented color 2 (hover state)		
		accent3			- theme accented color 3
		accent3_hover	- theme accented color 3 (hover state)		
		
		// Headers, text and links
		text			- main content
		text_light		- post info
		text_dark		- headers
		inverse_text	- text on accented background
		inverse_light	- post info on accented background
		inverse_dark	- headers on accented background
		inverse_link	- links on accented background
		inverse_hover	- hovered links on accented background
		
		// Block's border and background
		bd_color		- border for the entire block
		bg_color		- background color for the entire block
		bg_image, bg_image_position, bg_image_repeat, bg_image_attachment  - first background image for the entire block
		bg_image2,bg_image2_position,bg_image2_repeat,bg_image2_attachment - second background image for the entire block
		
		// Alternative colors - highlight blocks, form fields, etc.
		alter_text		- text on alternative background
		alter_light		- post info on alternative background
		alter_dark		- headers on alternative background
		alter_link		- links on alternative background
		alter_hover		- hovered links on alternative background
		alter_bd_color	- alternative border
		alter_bd_hover	- alternative border for hovered state or active field
		alter_bg_color	- alternative background
		alter_bg_hover	- alternative background for hovered state or active field 
		alter_bg_image, alter_bg_image_position, alter_bg_image_repeat, alter_bg_image_attachment - background image for the alternative block
		
		*/

		// Add color schemes
		bierbaum_add_color_scheme('original', array(

			'title'					=> esc_html__('Original', 'bierbaum'),

			// Accent colors
			'accent1'				=> '#f46333',
			'accent1_hover'			=> '#be4d27',
			'accent2'				=> '#323232',
			'accent2_hover'			=> '#525252',
			// 'accent3'				=> '',
			// 'accent3_hover'			=> '#3f3e40',
			
			// Headers, text and links colors
			'text'					=> '#555557',
			'text_light'			=> '#a8abae',
			'text_dark'				=> '#202020',
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#ffffff',
			'inverse_dark'			=> '#ffffff',
			'inverse_link'			=> '#ffffff',
			'inverse_hover'			=> '#ffffff',
			
			// Whole block border and background
			'bd_color'				=> '#cacaca',
			'bg_color'				=> '#f6f7f7',
			'bg_image'				=> bierbaum_get_file_url('images/texture-orange.jpg'),
			'bg_image_position'		=> 'left top',
			'bg_image_repeat'		=> 'repeat',
			'bg_image_attachment'	=> 'scroll',
			'bg_image2'				=> '',
			'bg_image2_position'	=> 'left top',
			'bg_image2_repeat'		=> 'repeat',
			'bg_image2_attachment'	=> 'scroll',
		// themerex_get_file_url(‘images/picture.png’)
			// Alternative blocks (submenu items, form's fields, etc.)
			'alter_text'			=> '#29a5d6',
			'alter_light'			=> '#acb4b6',
			'alter_dark'			=> '#232a34',
			'alter_link'			=> '#20c7ca',
			'alter_hover'			=> '#00adef',
			'alter_bd_color'		=> '#dddddd',
			'alter_bd_hover'		=> '#bbbbbb',
			'alter_bg_color'		=> '#f7f7f7',
			'alter_bg_hover'		=> '#f0f0f0',
			'alter_bg_image'			=> bierbaum_get_file_url('images/texture-grey.jpg'),
			'alter_bg_image_position'	=> 'left top',
			'alter_bg_image_repeat'		=> 'repeat',
			'alter_bg_image_attachment'	=> 'scroll',
			)
		);

		// Add color schemes
		bierbaum_add_color_scheme('scheme_1', array(

			'title'					=> esc_html__('Scheme 1', 'bierbaum'),

			// Accent colors
			'accent1'				=> '#98c137',
			'accent1_hover'			=> '#88c102',
			'accent2'				=> '#8e2b1a',
			'accent2_hover'			=> '#801a09',
			// 'accent3'				=> '',
			// 'accent3_hover'			=> '#3f3e40',
			
			// Headers, text and links colors
			'text'					=> '#555557',
			'text_light'			=> '#a8abae',
			'text_dark'				=> '#3f3e40',
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#ffffff',
			'inverse_dark'			=> '#ffffff',
			'inverse_link'			=> '#ffffff',
			'inverse_hover'			=> '#ffffff',
			
			// Whole block border and background
			'bd_color'				=> '#cacaca',
			'bg_color'				=> '#f6f7f7',
			'bg_image'				=> '',
			'bg_image_position'		=> 'left top',
			'bg_image_repeat'		=> 'repeat',
			'bg_image_attachment'	=> 'scroll',
			'bg_image2'				=> '',
			'bg_image2_position'	=> 'left top',
			'bg_image2_repeat'		=> 'repeat',
			'bg_image2_attachment'	=> 'scroll',
		
			// Alternative blocks (submenu items, form's fields, etc.)
			'alter_text'			=> '#29a5d6',
			'alter_light'			=> '#acb4b6',
			'alter_dark'			=> '#232a34',
			'alter_link'			=> '#20c7ca',
			'alter_hover'			=> '#00adef',
			'alter_bd_color'		=> '#dddddd',
			'alter_bd_hover'		=> '#bbbbbb',
			'alter_bg_color'		=> '#f7f7f7',
			'alter_bg_hover'		=> '#f0f0f0',
			'alter_bg_image'			=> '',
			'alter_bg_image_position'	=> 'left top',
			'alter_bg_image_repeat'		=> 'repeat',
			'alter_bg_image_attachment'	=> 'scroll',
			)
		);

		// Add color schemes
		bierbaum_add_color_scheme('scheme_2', array(

			'title'					=> esc_html__('Scheme 2', 'bierbaum'),

			// Accent colors
			'accent1'				=> '#0ebb8e',
			'accent1_hover'			=> '#03a57b',
			'accent2'				=> '#ee912a',
			'accent2_hover'			=> '#e77f0b',
			// 'accent3'				=> '',
			// 'accent3_hover'			=> '#3f3e40',
			
			// Headers, text and links colors
			'text'					=> '#555557',
			'text_light'			=> '#a8abae',
			'text_dark'				=> '#3f3e40',
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#ffffff',
			'inverse_dark'			=> '#ffffff',
			'inverse_link'			=> '#ffffff',
			'inverse_hover'			=> '#ffffff',
			
			// Whole block border and background
			'bd_color'				=> '#cacaca',
			'bg_color'				=> '#f6f7f7',
			'bg_image'				=> '',
			'bg_image_position'		=> 'left top',
			'bg_image_repeat'		=> 'repeat',
			'bg_image_attachment'	=> 'scroll',
			'bg_image2'				=> '',
			'bg_image2_position'	=> 'left top',
			'bg_image2_repeat'		=> 'repeat',
			'bg_image2_attachment'	=> 'scroll',
		
			// Alternative blocks (submenu items, form's fields, etc.)
			'alter_text'			=> '#29a5d6',
			'alter_light'			=> '#acb4b6',
			'alter_dark'			=> '#232a34',
			'alter_link'			=> '#20c7ca',
			'alter_hover'			=> '#00adef',
			'alter_bd_color'		=> '#dddddd',
			'alter_bd_hover'		=> '#bbbbbb',
			'alter_bg_color'		=> '#f7f7f7',
			'alter_bg_hover'		=> '#f0f0f0',
			'alter_bg_image'			=> '',
			'alter_bg_image_position'	=> 'left top',
			'alter_bg_image_repeat'		=> 'repeat',
			'alter_bg_image_attachment'	=> 'scroll',
			)
		);

		

		// Add color schemes
		bierbaum_add_color_scheme('scheme_3', array(

			'title'					=> esc_html__('Scheme 3', 'bierbaum'),

			// Accent colors
			'accent1'				=> '#da6666',
			'accent1_hover'			=> '#c85c5c',
			'accent2'				=> '#6f6274',
			'accent2_hover'			=> '#664d70',
			// 'accent3'				=> '',
			// 'accent3_hover'			=> '#3f3e40',
			
			// Headers, text and links colors
			'text'					=> '#555557',
			'text_light'			=> '#a8abae',
			'text_dark'				=> '#3f3e40',
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#ffffff',
			'inverse_dark'			=> '#ffffff',
			'inverse_link'			=> '#ffffff',
			'inverse_hover'			=> '#ffffff',
			
			// Whole block border and background
			'bd_color'				=> '#cacaca',
			'bg_color'				=> '#f6f7f7',
			'bg_image'				=> '',
			'bg_image_position'		=> 'left top',
			'bg_image_repeat'		=> 'repeat',
			'bg_image_attachment'	=> 'scroll',
			'bg_image2'				=> '',
			'bg_image2_position'	=> 'left top',
			'bg_image2_repeat'		=> 'repeat',
			'bg_image2_attachment'	=> 'scroll',
		
			// Alternative blocks (submenu items, form's fields, etc.)
			'alter_text'			=> '#29a5d6',
			'alter_light'			=> '#acb4b6',
			'alter_dark'			=> '#232a34',
			'alter_link'			=> '#20c7ca',
			'alter_hover'			=> '#00adef',
			'alter_bd_color'		=> '#dddddd',
			'alter_bd_hover'		=> '#bbbbbb',
			'alter_bg_color'		=> '#f7f7f7',
			'alter_bg_hover'		=> '#f0f0f0',
			'alter_bg_image'			=> '',
			'alter_bg_image_position'	=> 'left top',
			'alter_bg_image_repeat'		=> 'repeat',
			'alter_bg_image_attachment'	=> 'scroll',
			)
		);
		



		/* Font slugs:
		h1 ... h6	- headers
		p			- plain text
		link		- links
		info		- info blocks (Posted 15 May, 2015 by John Doe)
		menu		- main menu
		submenu		- dropdown menus
		logo		- logo text
		button		- button's caption
		input		- input fields
		*/

		// Add Custom fonts
		bierbaum_add_custom_font('h1', array(
			'title'			=> esc_html__('Heading 1', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '3.78em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '0.5em',
			'margin-bottom'	=> '0.15em'
			)
		);
		bierbaum_add_custom_font('h2', array(
			'title'			=> esc_html__('Heading 2', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '2.57em',
			'font-weight'	=> '300',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '0.6667em',
			'margin-bottom'	=> '0.56em'
			)
		);
		bierbaum_add_custom_font('h3', array(
			'title'			=> esc_html__('Heading 3', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '1.54em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '0.6667em',
			'margin-bottom'	=> '1em'
			)
		);
		bierbaum_add_custom_font('h4', array(
			'title'			=> esc_html__('Heading 4', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '1.16em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '1.2em',
			'margin-bottom'	=> '1.54em'
			)
		);
		bierbaum_add_custom_font('h5', array(
			'title'			=> esc_html__('Heading 5', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '1em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '1.2em',
			'margin-bottom'	=> '1.99em'
			)
		);
		bierbaum_add_custom_font('h6', array(
			'title'			=> esc_html__('Heading 6', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '0.75em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '1.25em',
			'margin-bottom'	=> '0.65em'
			)
		);
		bierbaum_add_custom_font('p', array(
			'title'			=> esc_html__('Text', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Lato',
			'font-size' 	=> '14px',
			'font-weight'	=> '400',
			'font-style'	=> '',
			'line-height'	=> '1.2em',
			'margin-top'	=> '',
			'margin-bottom'	=> '1em'
			)
		);
		bierbaum_add_custom_font('link', array(
			'title'			=> esc_html__('Links', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> ''
			)
		);
		bierbaum_add_custom_font('info', array(
			'title'			=> esc_html__('Post info', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> 'i',
			'line-height'	=> '1.3em',
			'margin-top'	=> '',
			'margin-bottom'	=> '1.5em'
			)
		);
		bierbaum_add_custom_font('menu', array(
			'title'			=> esc_html__('Main menu items', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Lato',
			'font-size' 	=> '1em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '1.8em',
			'margin-bottom'	=> '1.8em'
			)
		);
		bierbaum_add_custom_font('submenu', array(
			'title'			=> esc_html__('Dropdown menu items', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '',
			'margin-bottom'	=> ''
			)
		);
		bierbaum_add_custom_font('logo', array(
			'title'			=> esc_html__('Logo', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> 'Raleway',
			'font-size' 	=> '2.8571em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '0.75em',
			'margin-top'	=> '2.5em',
			'margin-bottom'	=> '2em'
			)
		);
		bierbaum_add_custom_font('button', array(
			'title'			=> esc_html__('Buttons', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> '',
			'line-height'	=> '1.3em'
			)
		);
		bierbaum_add_custom_font('input', array(
			'title'			=> esc_html__('Input fields', 'bierbaum'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> '',
			'line-height'	=> '1.3em'
			)
		);

	}
}





//------------------------------------------------------------------------------
// Skin's fonts
//------------------------------------------------------------------------------

// Add skin fonts in the used fonts list
if (!function_exists('bierbaum_filter_skin_used_fonts')) {
	//add_filter('bierbaum_filter_used_fonts', 'bierbaum_filter_skin_used_fonts');
	function bierbaum_filter_skin_used_fonts($theme_fonts) {
		$theme_fonts['Lato'] = 1;
		$theme_fonts['Raleway'] = 1;
		$theme_fonts['Open Sans'] = 1;
		return $theme_fonts;
	}
}

// Add skin fonts (from Google fonts) in the main fonts list (if not present).
// To use custom font-face you not need add it into list in this function
// How to install custom @font-face fonts into the theme?
// All @font-face fonts are located in "theme_name/css/font-face/" folder in the separate subfolders for the each font. Subfolder name is a font-family name!
// Place full set of the font files (for each font style and weight) and css-file named stylesheet.css in the each subfolder.
// Create your @font-face kit by using Fontsquirrel @font-face Generator (http://www.fontsquirrel.com/fontface/generator)
// and then extract the font kit (with folder in the kit) into the "theme_name/css/font-face" folder to install
if (!function_exists('bierbaum_filter_skin_list_fonts')) {
	//add_filter('bierbaum_filter_list_fonts', 'bierbaum_filter_skin_list_fonts');
	function bierbaum_filter_skin_list_fonts($list) {
		// Example:
		// if (!isset($list['Advent Pro'])) {
		//		$list['Advent Pro'] = array(
		//			'family' => 'sans-serif',																						// (required) font family
		//			'link'   => 'Advent+Pro:100,100italic,300,300italic,400,400italic,500,500italic,700,700italic,900,900italic',	// (optional) if you use Google font repository
		//			'css'    => bierbaum_get_file_url('/css/font-face/Advent-Pro/stylesheet.css')									// (optional) if you use custom font-face
		//			);
		// }

		if (!isset($list['Raleway'])) {
				$list['Raleway'] = array(
					'family' => 'sans-serif',																						// (required) font family
					'link'   => 'Raleway:400,500,600,700,300',	// (optional) if you use Google font repository
					);
		}

		if (!isset($list['Open Sans'])) {
				$list['Open Sans'] = array(
					'family' => 'sans-serif',																						// (required) font family
					'link'   => 'Open+Sans:400,300italic,400italic,600,600italic,700,700italic&subset=latin,latin-ext',	// (optional) if you use Google font repository
					);
		}

		if (!isset($list['Lato']))	$list['Lato'] = array('family'=>'sans-serif');

		return $list;
	}
}



//------------------------------------------------------------------------------
// Skin's stylesheets
//------------------------------------------------------------------------------
// Add skin stylesheets
if (!function_exists('bierbaum_action_skin_add_styles')) {
	//add_action('bierbaum_action_add_styles', 'bierbaum_action_skin_add_styles');
	function bierbaum_action_skin_add_styles() {
		// Add stylesheet files
		bierbaum_enqueue_style( 'bierbaum-skin-style', bierbaum_get_file_url('skin.css'), array(), null );
		if (file_exists(bierbaum_get_file_dir('skin.customizer.css')))
			bierbaum_enqueue_style( 'bierbaum-skin-customizer-style', bierbaum_get_file_url('skin.customizer.css'), array(), null );
	}
}

// Add skin inline styles
if (!function_exists('bierbaum_filter_skin_add_styles_inline')) {
	//add_filter('bierbaum_filter_add_styles_inline', 'bierbaum_filter_skin_add_styles_inline');
	function bierbaum_filter_skin_add_styles_inline($custom_style) {
		// Todo: add skin specific styles in the $custom_style to override
		//       rules from style.css and shortcodes.css
		// Example:
		//		$scheme = bierbaum_get_custom_option('body_scheme');
		//		if (empty($scheme)) $scheme = 'original';
		//		$clr = bierbaum_get_scheme_color('accent1');
		//		if (!empty($clr)) {
		// 			$custom_style .= '
		//				a,
		//				.bg_tint_light a,
		//				.top_panel .content .search_wrap.search_style_regular .search_form_wrap .search_submit,
		//				.top_panel .content .search_wrap.search_style_regular .search_icon,
		//				.search_results .post_more,
		//				.search_results .search_results_close {
		//					color:'.esc_attr($clr).';
		//				}
		//			';
		//		}
		return $custom_style;	
	}
}

// Add skin responsive styles
if (!function_exists('bierbaum_action_skin_add_responsive')) {
	//add_action('bierbaum_action_add_responsive', 'bierbaum_action_skin_add_responsive');
	function bierbaum_action_skin_add_responsive() {
		$suffix = bierbaum_param_is_off(bierbaum_get_custom_option('show_sidebar_outer')) ? '' : '-outer';
		if (file_exists(bierbaum_get_file_dir('skin.responsive'.($suffix).'.css'))) 
			bierbaum_enqueue_style( 'theme-skin-responsive-style', bierbaum_get_file_url('skin.responsive'.($suffix).'.css'), array(), null );
	}
}

// Add skin responsive inline styles
if (!function_exists('bierbaum_filter_skin_add_responsive_inline')) {
	//add_filter('bierbaum_filter_add_responsive_inline', 'bierbaum_filter_skin_add_responsive_inline');
	function bierbaum_filter_skin_add_responsive_inline($custom_style) {
		return $custom_style;	
	}
}

// Add skin.less into list files for compilation
if (!function_exists('bierbaum_filter_skin_compile_less')) {
	//add_filter('bierbaum_filter_compile_less', 'bierbaum_filter_skin_compile_less');
	function bierbaum_filter_skin_compile_less($files) {
		if (file_exists(bierbaum_get_file_dir('skin.less'))) {
		 	$files[] = bierbaum_get_file_dir('skin.less');
		}
		return $files;	
	}
}



//------------------------------------------------------------------------------
// Skin's scripts
//------------------------------------------------------------------------------

// Add skin scripts
if (!function_exists('bierbaum_action_skin_add_scripts')) {
	//add_action('bierbaum_action_add_scripts', 'bierbaum_action_skin_add_scripts');
	function bierbaum_action_skin_add_scripts() {
		if (file_exists(bierbaum_get_file_dir('skin.js')))
			bierbaum_enqueue_script( 'theme-skin-script', bierbaum_get_file_url('skin.js'), array(), null );
		if (bierbaum_get_theme_option('show_theme_customizer') == 'yes' && file_exists(bierbaum_get_file_dir('skin.customizer.js')))
			bierbaum_enqueue_script( 'theme-skin-customizer-script', bierbaum_get_file_url('skin.customizer.js'), array(), null );
		if (file_exists(bierbaum_get_file_dir('form_autocomplete.js')))
            bierbaum_enqueue_script( 'theme-skin-link-script', bierbaum_get_file_url('form_autocomplete.js'), array(), null );
	}
}

// Add skin scripts inline
if (!function_exists('bierbaum_action_skin_add_scripts_inline')) {
	//add_action('bierbaum_action_add_scripts_inline', 'bierbaum_action_skin_add_scripts_inline');
	function bierbaum_action_skin_add_scripts_inline() {
		// Todo: add skin specific scripts
		// Example:
		// echo '<script type="text/javascript">'
		//	. 'jQuery(document).ready(function() {'
		//	. "if (BIERBAUM_GLOBALS['theme_font']=='') BIERBAUM_GLOBALS['theme_font'] = '" . bierbaum_get_custom_font_settings('p', 'font-family') . "';"
		//	. "BIERBAUM_GLOBALS['theme_skin_color'] = '" . bierbaum_get_scheme_color('accent1') . "';"
		//	. "});"
		//	. "< /script>";
	}
}
?>